<?php 
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 * Blockquote Widget.
 *
 * @version       1.0
 * @author        themebubble
 * @category      Classes
 * @author        themebubble
 */
class RS_Blog_Masonry_Widget extends Widget_Base {

  public function get_name() {
    return 'rs-blog-masonry-widget';
  }

  public function get_title() {
    return 'Blog Masonry';
  }

  public function get_icon() {
    return 'elem_icon vc_image_blog_masonry_icon';
  }

  public function get_script_depends() {
    return ['isotope-pkg'];
  }

  public function get_categories() {
    return array('blogit-elementor');
  }


  protected function _register_controls() {
    $this->start_controls_section(
      'blog_masonry_general_settings',
      array(
        'label' => esc_html__( 'General' , 'blogit-addons' )
      )
    );

    $this->add_control(
      'cats',
      array(
        'label'       => esc_html__( 'Select Categories', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT2,
        'multiple'    => true,
        'options'     => array_flip(rs_element_values( 'categories', array(
          'sort_order'  => 'ASC',
          'taxonomy'    => 'category',
          'hide_empty'  => false,
        ) )),
        'label_block' => true,
      )
    );

    $this->add_control(
      'post_per_page',
      array(
        'label'       => esc_html__( 'Post Per Page', 'blogit-addons' ),
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
      )
    );

    $this->add_control(
      'excerpt_length',
      array(
        'label'       => esc_html__( 'Excerpt Length', 'blogit-addons' ),
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
      )
    );

    $this->add_control(
      'pagination_style',
      array(
        'label'       => esc_html__( 'Pagination Style', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'default',
        'options'     => array(
          'default'         => 'Default',
          'load-more'       => 'Load More',
          'infinite-scroll' => 'Infinite Scroll'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_category',
      array(
        'label'       => esc_html__( 'Show Category', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_author',
      array(
        'label'       => esc_html__( 'Show Author', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_date',
      array(
        'label'       => esc_html__( 'Show Date', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_comment',
      array(
        'label'       => esc_html__( 'Show Comment', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_views',
      array(
        'label'       => esc_html__( 'Show Views', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'orderby',
      array(
        'label'       => esc_html__( 'Order By', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array_flip(array(
          'ID'            => 'ID',
          'Author'        => 'author',
          'Post Title'    => 'title',
          'Date'          => 'date',
          'Last Modified' => 'modified',
          'Random Order'  => 'rand',
          'Comment Count' => 'comment_count',
          'Menu Order'    => 'menu_order',
        )),
        'label_block' => true,
      )
    );

    $this->end_controls_section();
    
  }

  protected function render() { 

    $settings  = $this->get_settings(); 

    $cats             = $settings['cats'];
    $post_per_page    = $settings['post_per_page'];
    $excerpt_length   = $settings['excerpt_length'];
    $pagination_style = $settings['pagination_style'];
    $show_category    = $settings['show_category'];
    $show_date        = $settings['show_date'];
    $show_comment     = $settings['show_comment'];
    $show_author      = $settings['show_author'];
    $show_views       = $settings['show_views'];
    $orderby          = $settings['orderby'];

    if (get_query_var('paged')) {
      $paged = get_query_var('paged');
    } elseif (get_query_var('page')) {
      $paged = get_query_var('page');
    } else {
      $paged = 1;
    }

    $args = array(
      'paged'          => $paged,
      'orderby'        => $orderby,
      'posts_per_page' => $post_per_page,
    );

    if( $cats ) {
      $args['tax_query'] = array(
        array(
          'taxonomy' => 'category',
          'field'    => 'ids',
          'terms'    => $cats
        )
      );
    }

    $nav_args = array(
      'nav'            => $pagination_style,
      'template'       => 'masonry-layout',
      'show_category'  => $show_category,
      'show_date'      => $show_date,
      'show_author'    => $show_author,
      'show_views'     => $show_views,
      'excerpt_length' => $excerpt_length,
      'posts_per_page' => $post_per_page,
      'isotope'        => 1,
    );

    ob_start();

    $the_query = new \WP_Query(apply_filters('blogit_block_query_args', $args));
    $max_num_pages = $the_query->max_num_pages;
    ?>


    <div class="row tt-blog-masonry tt-recent-news">
     <div class="isotope isotope-content">
      <div class="grid-sizer col-xs-12 col-sm-6 col-md-2"></div>

      <?php while ($the_query -> have_posts()) : $the_query -> the_post(); ?>

      <div <?php post_class('isotope-item col-xs-12 col-sm-6 col-md-2'); ?>>
        <div class="tt-post type-2">
          <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
          <div class="tt-post-info">
            <?php blogit_blog_category($show_category); ?>
            <?php blogit_blog_title('c-h5'); ?>
            <?php blogit_blog_author_date($show_author, $show_date); ?>
            <?php blogit_blog_excerpt($excerpt_length); ?>
            <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
          </div>
        </div>
        <div class="empty-space marg-lg-b30 marg-xs-b30"></div>
      </div>

      <?php endwhile; wp_reset_postdata(); ?>
      </div>
      <?php blogit_paging_nav($max_num_pages, $nav_args); ?>
     </div>

    <?php

    $output = ob_get_clean();

    echo $output;

  }


}
Plugin::instance()->widgets_manager->register_widget_type( new RS_Blog_Masonry_Widget() );