<?php 
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 * Blockquote Widget.
 *
 * @version       1.0
 * @author        themebubble
 * @category      Classes
 * @author        themebubble
 */
class RS_Button_Widget extends Widget_Base {

  public function get_name() {
    return 'rs-button-widget';
  }

  public function get_title() {
    return 'Button';
  }

  public function get_icon() {
    return 'elem_icon vc_image_button';
  }

  public function get_categories() {
    return array('blogit-elementor');
  }


  protected function _register_controls() {
    $this->start_controls_section(
      'button_general_settings',
      array(
        'label' => esc_html__( 'General' , 'blogit-addons' )
      )
    );

    $this->add_control(
      'size',
      array(
        'label'       => esc_html__( 'Size', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'options'     => array_flip(array(
          'Very Small' => 'v-small',
          'Small'      => 'small',
          'Medium'     => 'medium',
          'Large'      => 'large',
          'Very Large' => 'v-large'
        )),
        'label_block' => true,
      )
    );

    $this->add_control(
      'btn_text',
      array(
        'label'       => esc_html__( 'Button Text', 'blogit-addons' ),
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
      )
    );

    $this->add_control(
      'btn_link',
      array(
        'label'       => esc_html__( 'Button Link', 'blogit-addons' ),
        'type'        => Controls_Manager::URL,
        'label_block' => true,
        'default'     => array('url' => '#')
      )
    );

    $this->end_controls_section();

    $this->start_controls_section('button_styling_section',
      array(
        'label' => esc_html__('Styling', 'blogit-addons'),
        'tab'   => Controls_Manager::TAB_STYLE,
      )
    );

    $this->add_control('bg_color', 
      array(
        'label' => esc_html__('Background Color', 'blogit-addons'),
        'type'  => Controls_Manager::COLOR,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2' => 'background: {{VALUE}};',
        ),
      )
    );

    $this->add_control('bg_hover_color', 
      array(
        'label' => esc_html__('Background Hover Color', 'blogit-addons'),
        'type'  => Controls_Manager::COLOR,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2:before' => 'background: {{VALUE}};',
        ),
      )
    );

    $this->add_control('border_color', 
      array(
        'label' => esc_html__('Border Color', 'blogit-addons'),
        'type'  => Controls_Manager::COLOR,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2' => 'border-color: {{VALUE}};',
        ),
      )
    );

    $this->add_control('text_color', 
      array(
        'label' => esc_html__('Text Color', 'blogit-addons'),
        'type'  => Controls_Manager::COLOR,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2' => 'color: {{VALUE}};',
        ),
      )
    );

    $this->add_control('text_hover_color', 
      array(
        'label' => esc_html__('Text Hover Color', 'blogit-addons'),
        'type'  => Controls_Manager::COLOR,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2:hover' => 'color: {{VALUE}};',
        ),
      )
    );

    $this->add_control('font_size', 
      array(
        'label' => esc_html__('Font Size', 'blogit-addons'),
        'type'  => Controls_Manager::TEXT,
        'label_block' => true,
        'selectors' => array(
          '{{WRAPPER}} .c-btn.type-1.color-2' => 'font-size: {{VALUE}};',
        ),
      )
    );

    $this->end_controls_section();


  }

  protected function render() { 

    $settings  = $this->get_settings(); 

    $size     = $settings['size'];
    $link     = $settings['btn_link'];
    $btn_text = $settings['btn_text'];

    $href      = ( !empty($link['url']) ) ? $link['url'] : '#';
    $target    = ( $link['is_external'] == 'on') ? '_blank' : '_self';

    $output = '<a class="c-btn type-1 c-btn-auto '.$size.' style-2 color-2" target="'.esc_attr($target).'" href="'.esc_html($href).'"><span>'.esc_html($btn_text).'</span></a>';

    echo $output;

  }


}
Plugin::instance()->widgets_manager->register_widget_type( new RS_Button_Widget() );