<?php 
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 * Blockquote Widget.
 *
 * @version       1.0
 * @author        themebubble
 * @category      Classes
 * @author        themebubble
 */
class RS_Featured_Blog_Widget extends Widget_Base {

  public function get_name() {
    return 'rs-featured-blog-widget';
  }

  public function get_title() {
    return 'Featured Blog';
  }

  public function get_icon() {
    return 'elem_icon vc_image_featured_blog_icon';
  }

  public function get_script_depends() {
    return ['isotope-pkg'];
  }

  public function get_categories() {
    return array('blogit-elementor');
  }


  protected function _register_controls() {
    $this->start_controls_section(
      'featured_blog_general_settings',
      array(
        'label' => esc_html__( 'General' , 'blogit-addons' )
      )
    );

    $this->add_control(
      'style',
      array(
        'label'       => esc_html__( 'Style', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'style1',
        'options'     => array_flip(array(
          'Style 1'  => 'style1',
          'Style 2'  => 'style2',
          'Style 3'  => 'style4',
          'Style 4'  => 'style5',
          'Style 5'  => 'style6',
          'Style 6'  => 'style7',
          'Style 7'  => 'style8',
          'Style 8'  => 'style9',
          'Style 9'  => 'style10',
          'Style 10' => 'style11',
        )),
        'label_block' => true,
      )
    );

    $this->add_control(
      'cats',
      array(
        'label'       => esc_html__( 'Select Categories', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT2,
        'multiple'    => true,
        'options'     => array_flip(rs_element_values( 'categories', array(
          'sort_order'  => 'ASC',
          'taxonomy'    => 'category',
          'hide_empty'  => false,
        ) )),
        'label_block' => true,
      )
    );

    $this->add_control(
      'post_per_page',
      array(
        'label'       => esc_html__( 'Post Per Page', 'blogit-addons' ),
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
        'default'     => 3
      )
    );

    $this->add_control(
      'show_category',
      array(
        'label'       => esc_html__( 'Show Category', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_author',
      array(
        'label'       => esc_html__( 'Show Author', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_date',
      array(
        'label'       => esc_html__( 'Show Date', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_comment',
      array(
        'label'       => esc_html__( 'Show Comment', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_views',
      array(
        'label'       => esc_html__( 'Show Views', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'orderby',
      array(
        'label'       => esc_html__( 'Order By', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'ID',
        'options'     => array_flip(array(
          'ID'            => 'ID',
          'Author'        => 'author',
          'Post Title'    => 'title',
          'Date'          => 'date',
          'Last Modified' => 'modified',
          'Random Order'  => 'rand',
          'Comment Count' => 'comment_count',
          'Menu Order'    => 'menu_order',
        )),
        'label_block' => true,
      )
    );

    $this->end_controls_section();
    
  }

  protected function render() { 

    $settings  = $this->get_settings(); 

    $cats           = $settings['cats'];
    $post_per_page  = $settings['post_per_page'];
    $show_category  = $settings['show_category'];
    $show_date      = $settings['show_date'];
    $show_comment   = $settings['show_comment'];
    $show_author    = $settings['show_author'];
    $show_views     = $settings['show_views'];
    $orderby        = $settings['orderby'];
    $style          = $settings['style'];

    $args = array(
      'orderby'        => $orderby,
      'posts_per_page' => $post_per_page,
      'meta_query'     => array(array('key' => '_thumbnail_id')),
    );

    if( $cats ) {
      $args['tax_query'] = array(
        array(
          'taxonomy' => 'category',
          'field'    => 'ids',
          'terms'    => $cats
        )
      );
    }

    if (!empty($exclude_posts)) {
      $exclude_posts_arr = explode(',',$exclude_posts);
      if (is_array($exclude_posts_arr) && count($exclude_posts_arr) > 0) {
        $args['post__not_in'] = array_map('intval',$exclude_posts_arr);
      }
    }

    $layout = blogit_get_opt('main-layout');
    switch ($layout) {
      case 'right_sidebar':
      case 'left_sidebar':
        $offset_class = '';
        break;
      default:
        $offset_class = 'col-lg-offset-2';
        # code...
        break;
    }

    $args = apply_filters('blogit_block_query_args', $args);
    $isotope_html = $end_div = $isotope_class = '';
    if($style == 'style1') {
      wp_enqueue_script('isotope-pkg');
      $isotope_html = '<div class="isotope isotope-content"><div class="grid-sizer col-xs-12 col-sm-6 col-md-2"></div>';
      $end_div      = '</div>';
      $isotope_class = ' isotope-item';
    }

    ob_start();

    $the_query = new \WP_Query($args);

      switch ($style) {
        case 'style1':
        case 'style4': ?>
          <div class="row">
          <?php echo wp_kses_post($isotope_html); ?>
          <?php $i = 0;
            while ($the_query -> have_posts()) : $the_query -> the_post();
              if($i == 0 || $style == 'style4'): ?>
                <div <?php post_class('col-sm-12'.$isotope_class); ?>>
                  <div class="tt-post tt-border-radius">
                    <?php blogit_post_format('blogit-big', 'img-responsive', true, '', 'tt-icon-size-large'); ?>
                    <div class="tt-post-info">
                      <?php blogit_blog_category($show_category); ?>
                      <?php blogit_blog_title(); ?>
                      <?php blogit_blog_author_date($show_author, $show_date); ?>
                      <?php blogit_blog_excerpt(30); ?>
                      <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
                    </div>
                  </div>
                  <div class="empty-space marg-lg-b30"></div>
                </div>
              <?php else: ?>
                <div <?php post_class('col-sm-6'.$isotope_class); ?>>
                  <div class="tt-post tt-border-radius type-2">
                      <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
                      <div class="tt-post-info">
                        <?php blogit_blog_category($show_category); ?>
                        <?php blogit_blog_title('c-h5'); ?>
                        <?php blogit_blog_author_date($show_author, $show_date); ?>
                        <?php blogit_blog_excerpt(15); ?>
                        <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
                      </div>
                  </div>
                  <div class="empty-space marg-lg-b30 marg-xs-b30"></div>
                </div>
                <div class="empty-space marg-lg-b55 marg-sm-b30"></div>
              <?php
              endif;
              $i++;
            endwhile;
            wp_reset_postdata(); ?>
            <?php echo wp_kses_post($end_div); ?>
          </div>
          <?php
          break;
        case 'style2': ?>

          <div class="row">
            <?php $i = 0; while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
            <?php if($i == 0): ?>
            <div <?php post_class('col-sm-8'); ?>>

              <div class="tt-post tt-border-radius type-2">
                <?php blogit_post_format('blogit-big-alt-2', 'img-responsive'); ?>
                <div class="tt-post-info">
                  <?php blogit_blog_category($show_category); ?>
                  <?php blogit_blog_title('c-h4', true); ?>
                  <?php blogit_blog_author_date($show_author, $show_date); ?>
                  <?php blogit_blog_excerpt(); ?>
                  <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
                </div>
              </div>
              <div class="empty-space marg-xs-b30"></div>
            </div>
            <?php else: ?>

            <div <?php post_class('col-sm-4'); ?>>
              <div class="tt-post type-4">
                <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
                <div class="tt-post-info">
                  <?php blogit_blog_title('c-h5'); ?>
                  <?php blogit_blog_author_date($show_author, $show_date); ?>
                </div>
              </div>
              <?php echo (($the_query->current_post + 1) !== ( $the_query->post_count )) ? '<div class="empty-space marg-lg-b25"></div>':''; ?>
            </div>
            <?php endif; $i++; ?>
            <?php endwhile;
            wp_reset_postdata(); ?>
          </div>
          <?php

          break;
        case 'style5': ?>
          <div class="row tt-post-two-col">
            <?php while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
            <div <?php post_class('col-sm-12 tt-featured-blog-style5 tt-post-two-col-item'); ?>>
              <div class="tt-post text-center">
                <?php blogit_post_format('blogit-big', 'img-responsive', true, '', 'tt-icon-size-large'); ?>
                <div class="tt-post-info">
                  <?php blogit_blog_category($show_category); ?>
                  <?php blogit_blog_title(); ?>
                  <?php blogit_blog_author_date($show_author, $show_date); ?>
                  <?php blogit_blog_excerpt(40); ?>
                  <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
                </div>
              </div>
              <div class="empty-space marg-lg-b30"></div>
            </div>
            <?php endwhile; wp_reset_postdata(); ?>
          </div>
          <?php
          # code...
          break;

        case 'style6':
        case 'style7':
        case 'style9':
        ?>
        <div class="row tt-post-two-col">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
            <div <?php post_class('col-sm-6 tt-featured-blog-'.$style.' tt-post-two-col-item'); ?>>
              <div class="tt-post type-2 text-center">
                  <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
                  <div class="tt-post-info">
                    <?php blogit_blog_category($show_category); ?>
                    <?php blogit_blog_title('c-h4', true); ?>
                    <?php blogit_blog_author_date($show_author, $show_date); ?>
                    <?php blogit_blog_excerpt(15); ?>
                  </div>
              </div>
              <div class="empty-space marg-lg-b30 marg-xs-b30"></div>
            </div>
          <?php endwhile; wp_reset_postdata(); ?>
          </div>
          <?php
          break;

        case 'style8': ?>
          <div class="row tt-post-two-col">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
            <div <?php post_class('col-sm-6 tt-featured-blog-'.$style.' tt-post-two-col-item'); ?>>
              <div class="tt-post type-2 text-center">
                  <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
                  <div class="tt-post-info">
                    <?php blogit_blog_category($show_category); ?>
                    <?php blogit_blog_title('c-h4', true); ?>
                    <?php blogit_blog_author_date($show_author, $show_date); ?>
                  </div>
              </div>
              <div class="empty-space marg-lg-b30 marg-xs-b30"></div>
            </div>
          <?php endwhile; wp_reset_postdata(); ?>
          </div>
          <?php
          break;

        case 'style10': ?>
          <?php while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
            <div <?php post_class('tt-post tt-style1 tt-border-radius tt-post'); ?>>
              <div class="tt-post-info">
                <div class="empty-space  marg-lg-b15"></div>
                <div class="tt-blog-category text-center"> 
                  <?php 
                    $category = get_the_category(); 
                    if(is_array($category) && !empty($category)):
                      foreach($category as $cat): ?>
                        <a class="c-btn type-3 color-3" href="<?php echo esc_url(get_category_link($cat->term_id)); ?>"><?php echo esc_html($cat->cat_name); ?></a>
                     <?php 
                      endforeach;
                    endif;
                  ?>
                </div>
                <div class="empty-space marg-lg-b10"></div>  
                <a class="tt-post-title c-h3" href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                <div class="empty-space marg-lg-b5"></div>  
                <div class="tt-post-label">
                  <span class="tt-post-author-name vcard"><a class="url fn n" href="<?php echo get_the_author_link(); ?>"><?php echo get_the_author(); ?></a></span>
                  <span class="tt-post-date"><?php echo get_the_date(get_option('date_format')); ?></span>
                </div>
              </div>
              <?php blogit_post_format('blogit-big-alt-3', 'img-responsive'); ?>
            </div>
            <div class="empty-space  marg-lg-b25"></div>
          <?php endwhile; wp_reset_postdata(); 
          break;

        case 'style11': 
          $post_count = $the_query->post_count;
        ?>

        <?php 
          for ($i = 0; $i < 1; $i++): $the_query -> the_post(); 
            $bg = wp_get_attachment_image_src( get_post_thumbnail_id(get_the_ID()), 'full' );
            $bg = (is_array($bg) && isset($bg[0])) ? $bg[0]:'';
        ?>
        <div class="tt-post tt-style2 tt-parallax-on background-block text-center" style="background-image: url(<?php echo esc_url($bg); ?>);">
          <div class="container">
            <div class="row">
              <div <?php post_class('col-lg-6 col-lg-offset-3'); ?>>
                <div class="tt-post-info">
                  <div class="empty-space marg-lg-b75 marg-sm-b35"></div>
                  <div class="tt-blog-category text-center">
                  <?php 
                    $category = get_the_category(); 
                    if(is_array($category) && !empty($category)):
                      foreach($category as $cat): ?>
                        <a class="c-btn type-3 color-2" href="<?php echo esc_url(get_category_link($cat->term_id)); ?>"><?php echo esc_html($cat->cat_name); ?></a>
                     <?php 
                      endforeach;
                    endif;
                  ?>
                  </div>
                  <div class="empty-space marg-lg-b10"></div>  
                  <a class="tt-post-title c-h2" href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                  <div class="empty-space  marg-lg-b5"></div>  
                  <div class="tt-post-label">
                    <span class="tt-post-author-name vcard"><a class="url fn n" href="<?php echo get_the_author_link(); ?>"><?php echo get_the_author(); ?></a></span>
                    <span class="tt-post-date"><?php echo get_the_date(get_option('date_format')); ?></span>
                  </div>
                  <div class="empty-space marg-lg-b140 marg-sm-b20"></div>
                </div>
              </div>


            </div>
          </div>
        </div>
        <?php
          if (!$the_query -> have_posts()) :
            break;
          endif; ?>
        <?php endfor; ?>

        <?php 
          $small_previews_count = $the_query->post_count - 1; 
          if ($the_query -> have_posts() && $small_previews_count > 0):
              $posts_per_column = $post_per_page - 1;
        ?>
        <div class="tt-post-wrap tt-style3">
          <div class="tt-small-post-wrapper container">
            <div class="row">

              <?php for ($i = 0; $i < $posts_per_column; $i++):
                  if (!$the_query -> have_posts()) :
                    break;
                  endif;
                  $the_query -> the_post();
              ?>
              <div <?php post_class('col-xs-6 col-sm-4 col-lg-3'); ?>>
                <div class="tt-post style1 type-3">
                  <?php blogit_post_format('blogit-big-alt-2', 'img-responsive', true, '', 'tt-icon-size-medium'); ?>
                  <div class="tt-post-info">
                    <?php blogit_blog_category($show_category); ?>
                    <?php blogit_blog_title('c-h5', true); ?>
                    <?php blogit_blog_author_date($show_author, $show_date); ?>
                  </div>
                  <div class="empty-space  marg-lg-b15"></div> 
                </div>
              </div>
              <?php endfor; ?>

            </div>
          </div>
        </div>
        <?php endif; wp_reset_postdata();
        break;


        default:
          # code...
          break;
      }

      $output = ob_get_clean();

      echo $output;

  }


}
Plugin::instance()->widgets_manager->register_widget_type( new RS_Featured_Blog_Widget() );