<?php 
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 * Blockquote Widget.
 *
 * @version       1.0
 * @author        themebubble
 * @category      Classes
 * @author        themebubble
 */
class RS_Recent_News_Masonry_Widget extends Widget_Base {

  public function get_name() {
    return 'rs-recent-news-widget';
  }

  public function get_title() {
    return 'Recent News';
  }

  public function get_icon() {
    return 'elem_icon vc_image_recent_news_icon';
  }

  public function get_categories() {
    return array('blogit-elementor');
  }


  protected function _register_controls() {
    $this->start_controls_section(
      'recent_news_general_settings',
      array(
        'label' => esc_html__( 'General' , 'blogit-addons' )
      )
    );

    $this->add_control(
      'style',
      array(
        'label'       => esc_html__( 'Style', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'style1',
        'options'     => array_flip(array(
          'Style 1'  => 'style1',
          'Style 2'  => 'style2',
        )),
        'label_block' => true,
      )
    );

    $this->add_control(
      'post_per_page',
      array(
        'label'       => esc_html__( 'Post Per Page', 'blogit-addons' ),
        'default'     => 3,
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
      )
    );

    $this->add_control(
      'excerpt_length',
      array(
        'label'       => esc_html__( 'Excerpt Length', 'blogit-addons' ),
        'default'     => 35,
        'type'        => Controls_Manager::TEXT,
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_pagination',
      array(
        'label'        => esc_html__( 'Show Pagination', 'blogit-addons' ),
        'type'         => Controls_Manager::SELECT,
        'default'      => 'yes',
        'label_block'  => true,
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
      )
    );

    $this->add_control(
      'pagination_style',
      array(
        'label'       => esc_html__( 'Pagination Style', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'default',
        'options'     => array(
          'default'         => 'Default',
          'load-more'       => 'Load More',
          'infinite-scroll' => 'Infinite Scroll'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_category',
      array(
        'label'       => esc_html__( 'Show Category', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_author',
      array(
        'label'       => esc_html__( 'Show Author', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_date',
      array(
        'label'       => esc_html__( 'Show Date', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_comment',
      array(
        'label'       => esc_html__( 'Show Comment', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'show_views',
      array(
        'label'       => esc_html__( 'Show Views', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'yes',
        'options'     => array(
          'yes'       => 'Yes',
          'no'        => 'No'
        ),
        'label_block' => true,
      )
    );

    $this->add_control(
      'orderby',
      array(
        'label'       => esc_html__( 'Order By', 'blogit-addons' ),
        'type'        => Controls_Manager::SELECT,
        'default'     => 'ID',
        'options'     => array_flip(array(
          'ID'            => 'ID',
          'Author'        => 'author',
          'Post Title'    => 'title',
          'Date'          => 'date',
          'Last Modified' => 'modified',
          'Random Order'  => 'rand',
          'Comment Count' => 'comment_count',
          'Menu Order'    => 'menu_order',
        )),
        'label_block' => true,
      )
    );

    $this->end_controls_section();

    
  }

  protected function render() { 

    $settings  = $this->get_settings(); 

    $atts = array(
      'style'            => $settings['style'],
      'post_per_page'    => $settings['post_per_page'],
      'excerpt_length'   => $settings['excerpt_length'],
      'show_pagination'  => $settings['show_pagination'],
      'pagination_style' => $settings['pagination_style'],
      'show_category'    => $settings['show_category'],
      'show_date'        => $settings['show_date'],
      'show_comment'     => $settings['show_comment'],
      'show_author'      => $settings['show_author'],
      'show_views'       => $settings['show_views'],
      'orderby'          => $settings['orderby']
    );

    echo rs_recent_news($atts);
    
  }


}
Plugin::instance()->widgets_manager->register_widget_type( new RS_Recent_News_Masonry_Widget() );