<?php if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.
/**
 *
 * Social API Class
 * API class
 *
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if(!class_exists('RS_Social_API')) {
  class RS_Social_API {

    private static $caching_time = 10800;

    public function rs_get_social_counter($service_id, $user_id, $fb_token = '') {
      $count = 0;
      $cache_period = self::$caching_time;
      switch ($service_id) {
        case 'facebook':
          $count = $this->rs_get_facebook_social_count($user_id, $cache_period, $fb_token);
          break;
        case 'twitter':
          $count = $this->rs_get_twitter_social_count($user_id, $cache_period);
          break;
        case 'youtube':
          $count = $this->rs_get_youtube_social_count($user_id, $cache_period);
          break;
      }
      $count = $this->rs_format_followers(intval( $count));
      return $count;
    }

    public function rs_get_google_plus_count($user_id, $cache_period) {
      $count      = 0;
      $cache_key = 'googleplus_count' . $user_id;
      $googleplus = get_transient($cache_key);

      if ( $googleplus == false) {
        $data = @$this->rs_get_json('https://www.googleapis.com/plus/v1/people/'.$user_id.'?key=AIzaSyCaAH56Eueojnrznl39H0AqXowespGuWEM');
        if (!empty( $data['circledByCount'])) {
          $count = (int) $data['circledByCount'];
        } else {
          $data = @$this->rs_get_url( 'https://plus.google.com/'.$user_id.'/posts' );
          $pattern    = "/<span role=\"button\" class=\"d-s o5a\" tabindex=\"0\">(.*?)<\/span>/";
          preg_match($pattern, $data, $matches);
          if ( ! empty( $matches[1] ) ) {
            $expl_maches = explode( ' ', trim($matches[1]));
            $count       = str_replace( array('.', ','), array(''), $expl_maches[0]);
          }
        }
        set_transient($cache_key, $count, $cache_period);

      } else {
        $count = $googleplus;
      }

      return $count;
    }

    public function rs_get_youtube_social_count( $user_id, $cache_period ) {

      $cache_key     = 'youtube_count' . $user_id;
      $youtube_count = get_transient( $cache_key );
      $count         = 0;
      if ($youtube_count == false) {
        $url       = 'https://www.googleapis.com/youtube/v3/channels?part=statistics&key=AIzaSyBqKo542QYt8lixFlaHSl5FIrc_crd2p-I';
        $search_id = str_replace( 'channel/', '', $user_id );

        if ( strpos( $user_id, 'channel/' ) === 0 ) {
          $url .= '&id='.$search_id;
        } else {
          $url .= '&forUsername='.$search_id;
        }

        $data            = $this->rs_get_json( $url );
        $subscriberCount = isset( $data['items'][0]['statistics']['subscriberCount'] ) ? $data['items'][0]['statistics']['subscriberCount'] : '';

        if ( ! empty( $subscriberCount ) ) {
          $count = (int) $subscriberCount;
        }

        set_transient( $cache_key, $count, $cache_period );

      } else {
        $count = $youtube_count;
      }

      return $count;
    }

    public function rs_get_twitter_social_count( $user_id, $cache_period) {
      $cache_key = 'twitter_count' . $user_id;
      $twitter_count = get_transient( $cache_key );
      
      if ( $twitter_count == false) {

        $twitter_worked = false;

        $data = $this->rs_get_url('https://twitter.com/'.$user_id);

        if ( $data !== false ) {
          $pattern = "/title=\"(.*)\"(.*)data-nav=\"followers\"/i";
          preg_match_all( $pattern, $data, $matches );
          if ( ! empty( $matches[1][0] ) ) {
            $counter_fix = $this->rs_extract_numbers_from_string( htmlentities( $matches[1][0] ) );

            $count = (int) $counter_fix;

            if ( ! empty( $count ) and is_numeric( $count ) ) {
              $twitter_worked = true;
            }
          }
        }


        if ( $twitter_worked === false ) {
          if ( ! class_exists( 'RS_TwitterApiClient' ) ) {
            require_once 'class-twitter-client-api.php';
            $Client = new RS_TwitterApiClient;
            $Client->set_oauth( YOUR_CONSUMER_KEY, YOUR_CONSUMER_SECRET, SOME_ACCESS_KEY, SOME_ACCESS_SECRET );
            try {
              $path = 'users/show';
              $args = array( 'screen_name' => $user_id );
              $data = @$Client->call( $path, $args, 'GET' );
              if ( ! empty( $data['followers_count'] ) ) {
                $count = (int) $data['followers_count'];
              }
            } catch ( TwitterApiException $Ex ) {
            }
          }
        }

        set_transient( $cache_key, $count, $cache_period );

      } else {
        $count = $twitter_count;
      }

      return $count;
    }

    public function rs_get_facebook_social_count($page_id, $cache_period, $fb_token = '' ) {
      $facebook_count = get_transient('counter_facebook' . $page_id );
      $page_id        = preg_replace( '/\s+/', '', $page_id );
      $access_token   = (!empty($fb_token)) ? $fb_token:'';

      if ( ! $facebook_count && $page_id && $access_token ) {
        $count    = 0;
        $response = wp_remote_get('https://graph.facebook.com/v3.0/'.$page_id.'?access_token='.$access_token.'&fields=fan_count');
        $response = isset( $response['body'] ) ? json_decode( $response['body'] ) : '';

        if ( ! is_wp_error( $response ) ) {
          $response = (array)$response;
          if ( isset( $response['fan_count'] ) ) {
            $count = $response['fan_count'];
          }
        }

        set_transient( 'counter_facebook' . $page_id , $count, $cache_period );
      } else {
        $count = $facebook_count;
      }

      if ( $count != 0 ) {
        set_transient( 'counter_facebook', $count, $cache_period );
      }

      return $count;
    }

    public function rs_format_followers( $followers ) {

      if ( $followers >= 1000000 ) {
        $followers = number_format_i18n( $followers / 1000000, 2 ) . 'm';
      } elseif ( $followers >= 10000 ) {
        $followers = number_format_i18n( $followers / 1000, 1 ) . 'k';
      } else {
        $followers = number_format_i18n( $followers );
      }
      return $followers;
    }

    public function rs_get_url_wordpress( $url ) {
      $response = wp_remote_get( $url, array(
        'timeout'    => 10,
        'sslverify'  => false,
        'user-agent' => 'Mozilla/5.0 (Windows NT 6.3; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0'
      ) );

      if (is_wp_error( $response)) {
        return false;
      }

      $request_result = wp_remote_retrieve_body($response);

      if ( empty( $request_result)) {
        return false;
      }

      return $request_result;
    }

    private function rs_get_url($url) {
      return $this->rs_get_url_wordpress($url);
    }

    private function rs_get_json( $url ) {
      return json_decode( $this->rs_get_url($url), true);
    }

    private function rs_extract_numbers_from_string($string) {
      $output = '';
      foreach ( str_split( $string ) as $char ) {
        if ( is_numeric( $char ) ) {
          $output .= $char;
        }
      }

      return $output;
    }

  }
}
