<?php
/**
 *
 * RS Blog
 * @since 1.0.0
 * @version 1.1.0
 *
 */
function rs_hand_picked_blog( $atts, $content = '', $id = '' ) {

  extract( shortcode_atts( array(
    'id'               => '',
    'class'            => '',
    'cats'             => 0,
    'orderby'          => 'ID',
    'post_per_page'    => '8',
    'show_category'    => 'yes',
    'show_date'        => 'yes',
    'show_views'       => 'yes',
    'show_comment'     => 'yes',
    'heading'          => '',
    'show_author'      => 'yes',
    'style'            => 'style1',
    'pagination'       => 'yes',
    'pagination_style' => 'default',
    'exclude_posts'    => '',
  ), $atts ) );

  $id    = ( $id ) ? ' id="'. esc_attr($id) .'"' : '';
  $class = ( $class ) ? ' '. $class : '';

  if (get_query_var('paged')) {
    $paged = get_query_var('paged');
  } elseif (get_query_var('page')) {
    $paged = get_query_var('page');
  } else {
    $paged = 1;
  }

  $layout = blogit_get_opt('main-layout');
  switch ($layout) {
    case 'right_sidebar':
    case 'left_sidebar':
      $col_big     = 'col-sm-6';
      $col_small   = 'col-xs-6 col-sm-4 col-lg-3';
      $col_style_7 = 'col-sm-4';
      $header_tag  = 'c-h4';
      $small       = false;
      break;
    
    default:
      $col_big     = 'col-sm-4';
      $col_small   = 'col-xs-6 col-sm-4 col-lg-2';
      $col_style_7 = 'col-sm-3';
      $header_tag  = 'c-h3';
      $small       = true;
      # code...
      break;
  }

  $args = array(
    'paged'          => $paged,
    'orderby'        => $orderby,
    'posts_per_page' => $post_per_page,
    'meta_query'     => array(array('key' => '_thumbnail_id')), 
  );

  if( $cats ) {
    $args['tax_query'] = array(
      array(
        'taxonomy' => 'category',
        'field'    => 'ids',
        'terms'    => explode(',', $cats)
      )
    );
  }

  if (!empty($exclude_posts)) {
    $exclude_posts_arr = explode(',',$exclude_posts);
    if (is_array($exclude_posts_arr) && count($exclude_posts_arr) > 0) {
      $args['post__not_in'] = array_map('intval',$exclude_posts_arr);
    }
  }

  $nav_args = array(
    'nav'            => $pagination_style,
    'template'       => 'hand-picked-style8',
    'show_category'  => $show_category,
    'show_date'      => $show_date,
    'show_author'    => $show_author,
    'show_views'     => $show_views,
    'excerpt_length' => 15,
    'posts_per_page' => $post_per_page,
    'isotope'        => 0,
  );

  update_option( 'posts_per_page', $post_per_page );

  $args = apply_filters('blogit_block_query_args', $args);

  ob_start();

  $the_query = new WP_Query($args); 
  $max_num_pages = $the_query->max_num_pages;

  switch ($style) {
    case 'style1':
    default: ?>
      <div class="row">
        <div class="post-grid-view">
        <?php $i = 0; while ($the_query -> have_posts()) : $the_query -> the_post(); ?>
          <?php echo blogit_post_grid($col_small); ?>
        <?php $i++; endwhile; wp_reset_postdata(); ?>
        </div>
      </div>
      <?php
      # code...
      break;

    case 'style2':
    case 'style3': ?>
      <div class="row">
        <div class="post-grid-view">
        <?php
          $col_big = ($style == 'style3') ? 'col-sm-6':$col_big; 
          $i = 0; while ($the_query -> have_posts()) : $the_query -> the_post(); 
          if($i == 0):
        ?>
          <div <?php post_class($col_big); ?>>

            <div class="tt-post tt-border-radius type-2">
              <?php blogit_post_format('blogit-big-alt-2', 'img-responsive', true); ?>
              <div class="tt-post-info">
                <?php blogit_blog_category($show_category); ?>
                <?php blogit_blog_title('c-h4', true); ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
                <?php blogit_blog_excerpt(); ?>
                <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
              </div>
            </div>
            <div class="empty-space marg-xs-b30"></div> 
          </div>
        <?php else:
          echo blogit_post_grid($col_small);
          endif;
          $i++; endwhile; wp_reset_postdata();
        ?>
        </div>
      </div>
      <?php
      # code...
      break;

    case 'style4': ?>
      <div class="row">
        <div class="post-grid-view tt-post-style4">
        <?php
          $i = 0; while ($the_query -> have_posts()) : $the_query -> the_post(); 
          if($i == 0):
            $image_src = blogit_get_image_src(get_post_thumbnail_id());
        ?>
          <div <?php post_class($col_big); ?>>

            <div class="tt-post tt-post-big custom-hover-image type-2">
              <div class="bg" style="background-image:url(<?php echo esc_url($image_src); ?>);">
                <a class="tt-mslide-link" href="<?php echo esc_url(get_the_permalink()); ?>"></a>
                <div class="tt-mslide-gradient"></div>
              </div>
              <div class="tt-post-info tt-white-meta">
                <?php blogit_blog_title('c-h3', true); ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
              </div>
            </div>
            <div class="empty-space marg-xs-b30"></div> 
          </div>
        <?php else:
          echo blogit_post_grid($col_small);
          endif;
          $i++; endwhile; wp_reset_postdata();
        ?>
        </div>
      </div>
      <?php
      break;
      case 'style5': ?>
        <div class="row tt-post-style5">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post(); $image_src = blogit_get_image_src(get_post_thumbnail_id()); ?>
          <div class="col-md-6">
            <div class="tt-post tt-post-big custom-hover-image type-2">
              <div class="bg" style="background-image:url(<?php echo esc_url($image_src); ?>);">
                <a class="tt-mslide-link" href="<?php echo esc_url(get_the_permalink()); ?>"></a>
                <div class="tt-mslide-gradient"></div>
              </div>
              <div class="tt-post-info tt-white-meta">
                <?php blogit_blog_title($header_tag, $small); ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
              </div>
            </div>
            <div class="empty-space marg-xs-b30 marg-lg-b30"></div> 
          </div>
          <?php endwhile; wp_reset_postdata(); ?>
        </div>
        <?php 
      # code...
      break;

      case 'style6': ?>
        <div class="row tt-post-style6 tt-handpicked-blog-style6">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
          <div <?php post_class($col_small); ?>>
            <div class="tt-post tt-border-radius type-2 style-3">
              <?php blogit_post_format('blogit-medium-ver', 'img-responsive', false, '', 'tt-icon-size-small'); ?>
              <div class="tt-post-info">
                <?php blogit_blog_title('c-h5', true, true, 7); ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
              </div>
            </div>
            <div class="empty-space marg-lg-b30 marg-sm-b30"></div>
          </div><!-- .col -->
          <?php endwhile; wp_reset_postdata(); ?>
        </div>
        <?php
        # code...
        break;

      case 'style7': ?>
        <div class="row tt-post-style6 tt-handpicked-blog-style7">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
          <div <?php post_class($col_style_7); ?>>
            <div class="tt-post tt-border-radius type-2 style-3">
              <?php blogit_post_format('blogit-medium-ver', 'img-responsive', true, '', 'tt-icon-size-medium'); ?>
              <div class="tt-post-info">
                <?php blogit_blog_title('c-h5', false, true, 25); // class, small, trim, length ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
              </div>
            </div>
            <div class="empty-space marg-lg-b30 marg-sm-b30"></div>
          </div><!-- .col -->
          <?php endwhile; wp_reset_postdata(); ?>
        </div>
        <?php
        break;

      case 'style8': ?>
        <div class="row">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
          <div <?php post_class('col-lg-12'); ?>>
            <div class="tt-post tt-border-radius type-10 style-1">
              <?php blogit_post_format('blogit-medium-ver', 'img-responsive', false, '', 'tt-icon-size-medium'); ?>
              <div class="tt-post-info">
                <?php blogit_blog_category($show_category); ?>
                <?php blogit_blog_title('c-h4', false, true, 25); ?>
                <?php blogit_blog_author_date($show_author, $show_date); ?>
                <?php blogit_blog_post_bottom('no', $show_views); ?>
              </div>
            </div>
            <div class="empty-space marg-lg-b20 marg-sm-b20"></div>
          </div><!-- .col -->
          <?php endwhile; wp_reset_postdata(); if($pagination == 'yes') : blogit_paging_nav($max_num_pages, $nav_args); endif; ?>
        </div>
        <?php
        break;

      case 'style9': 
      case 'style11': ?>
      <div class="tt-post-wrap tt-style1 post-grid-view">
        <?php if(!empty($heading)): ?>
          <div class="tt-title-block <?php echo ($style == 'style11') ? 'style11':'style1'; ?> type1">
            <h3 class="tt-title-text"><?php echo esc_html($heading); ?></h3>
          </div>
        <?php endif; ?>
        <?php if($style == 'style9'): ?>
          <div class="empty-space marg-lg-b20"></div>
        <?php endif; ?>
        <div class="row">
          <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
            <div <?php post_class('col-xs-6 col-sm-4 col-lg-3 post-handy-picked'); ?>>
              <div class="tt-post style1 type-3">
                <?php blogit_post_format('blogit-big-alt-2', 'img-responsive', true, '', 'tt-icon-size-medium'); ?>
                <div class="tt-post-info">
                  <?php blogit_blog_category($show_category); ?>
                  <?php blogit_blog_title('c-h5', true, false); ?>
                </div>
              </div> 
              <div class="empty-space marg-lg-b15"></div>                 
            </div>
            <div class="clearfix visible-md-block"></div>
          <?php endwhile; wp_reset_postdata(); ?>

      </div>
     </div><!-- .tt-post-wrap -->
     <?php
      break;

    case 'style10':
    ?>
      <div class="tt-content-wrapp tt-post-wrap tt-style2 post-grid-view">
        <div class="tt-block-inner">
          <?php if(!empty($heading)): ?>
            <div class="tt-title-block style11">
              <h3 class="tt-title-text"><?php echo esc_html($heading); ?></h3>
            </div>
          <?php endif; ?>
          <div class="row">
            <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
              <div <?php post_class('col-xs-6 col-sm-4 col-lg-3 post-handy-picked'); ?>>
                <div class="tt-post style1 type-3">
                  <?php blogit_post_format('blogit-big-alt-2', 'img-responsive', true, '', 'tt-icon-size-medium'); ?>
                  <div class="tt-post-info">
                    <?php blogit_blog_category($show_category); ?>
                    <?php blogit_blog_title('c-h5', true, false); ?>
                  </div>
                </div> 
                <div class="empty-space marg-lg-b15"></div>                 
              </div>
              <div class="clearfix visible-md-block"></div>
            <?php endwhile; wp_reset_postdata(); ?>
          </div>
        </div>
      </div><!-- .tt-post-wrap -->
      <?php 
    break;

    case 'style12': ?>
      <div class="row tt-post-wrap tt-handpicked-blog-style12 post-grid-view">
        <?php while ($the_query -> have_posts()) : $the_query -> the_post();?>
        <div <?php post_class('col-md-3 post-handy-picked'); ?>>
          <div class="tt-post">
            <?php blogit_post_format('blogit-medium-ver', 'img-responsive', true, '', 'tt-icon-size-medium'); ?>
            <div class="tt-post-info">
              <?php blogit_blog_category($show_category); ?>
              <?php blogit_blog_title('c-h5', true, true, 5); ?>
              <div class="empty-space  marg-lg-b5"></div>
              <?php blogit_blog_post_bottom('no', $show_views); ?>
            </div>
          </div>
        </div><!-- .isotope-item -->
        <?php endwhile; wp_reset_postdata(); if($pagination == 'yes') : blogit_paging_nav($max_num_pages); endif; ?>
      </div>
      <?php
      break;
  
  }

  $output = ob_get_clean();
  return $output;
}
add_shortcode( 'rs_hand_picked_blog', 'rs_hand_picked_blog' );
