<?php
/**
 * Latest posts widget
 *
 * @package blogit
 */
class blogit_WP_Latest_Posts_Widget extends WP_Widget
{
  function __construct()
  {
    $widget_ops = array('classname' => 'widget_latest_posts_entries', 'description' => esc_html__( 'Displays the most popular posts', 'blogit-addons' ) );
    parent::__construct('latest-posts', esc_html__( '- blogit: Popular Posts', 'blogit-addons' ), $widget_ops);

    $this-> alt_option_name = 'widget_latest_posts_entries';

  }

  function widget($args, $instance)
  {
    global $post;

    $cache = wp_cache_get('widget_latest_posts_entries', 'widget');

    if ( !is_array($cache) )
    {
      $cache = array();
    }
    if ( ! isset( $args['widget_id'] ) )
    {
      $args['widget_id'] = $this->id;
    }

    if ( isset( $cache[ $args['widget_id'] ] ) )
    {
      echo $cache[ $args['widget_id'] ];
      return;
    }

    ob_start();
    extract($args);
    echo $before_widget;
    $title = apply_filters('widget_title', empty($instance['title']) ? esc_html__( 'Popular Posts', 'blogit-addons' ) : $instance['title'], $instance, $this->id_base);
    if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
    {
      $number = 6;
    }

    $style = (empty($instance['style'])) ? 1:$instance['style'];
    $cat   = (!empty($instance['cat'])) ? $instance['cat']:'';

    $wp_query_args = array(
      'meta_query'          => array(array('key' => '_thumbnail_id')), 
      'orderby'             => 'meta_value_num', 
      'order'               => 'DESC', 
      'meta_key'            =>'post_views_count', 
      'posts_per_page'      => $number, 
      'no_found_rows'       => true, 
      'post_status'         => 'publish', 
      'ignore_sticky_posts' => true
    );

    if(!empty($cat)) {
      $wp_query_args['tax_query'] = array(
        array(
          'taxonomy' => 'category',
          'field'    => 'ids',
          'terms'    => explode( ',', $cat )
        )
      );
    }

    $r = new WP_Query($wp_query_args);
    if ($r->have_posts()) :


      switch ($style) {
        case 1:
        case 2:
        case 3:
        default:
          $post_count = ($style == 1) ? 1:$r->post_count;
        ?>
          <div class="tt-border-block tt-border-radius style-<?php echo esc_attr($style); ?>">
            <div class="tt-title-block type-2">
                <h3 class="tt-title-text"><?php echo esc_html($title);  ?></h3>
            </div>
            <div class="empty-space marg-lg-b15"></div>

            <?php for ($i = 0; $i < $post_count; $i ++): $r -> the_post(); ?>
            <div <?php post_class('tt-post type-3'); ?>>
              <?php blogit_post_format('blogit-medium-hor', 'img-responsive'); ?>
              <?php if($style == 3): ?>
                <div class="tt-post-count"><?php echo esc_html($i+1); ?></div>
              <?php endif; ?>
              <div class="tt-post-info">
                <a class="tt-post-title c-h5 small" href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                  <?php blogit_blog_author_date(); ?>
              </div>
            </div>
            <?php echo ($style == 2 || $style == 3) ? '<div class="marg-lg-b30"></div>':''; ?>
            <?php
              if (!$r -> have_posts()) :
                break;
              endif; ?>
            <?php endfor; ?>
            


            <?php echo ($style == 1) ?  '<div class="empty-space marg-lg-b30"></div>':''; ?>

            <?php

              $small_previews_count = $r->post_count - 1;


              if ($r -> have_posts() && $small_previews_count > 0 && $style == 1):

                $posts_per_column = $number - 1;
            ?>

            <ul class="tt-post-list type-2">
              <?php for ($i = 0; $i < $posts_per_column; $i++):

                if (!$r -> have_posts()) :
                  break;
                endif;
                $r -> the_post();
              ?>
              <li>
                <div class="tt-post type-7 clearfix">
                  <?php blogit_post_format('blogit-small-alt', 'img-responsive', false, '', 'tt-icon-size-small'); ?>
                  <div class="tt-post-info">
                    <?php blogit_blog_title('c-h6'); ?>
                    <?php blogit_blog_author_date(false); ?>
                  </div>
                </div>                                    
              </li>
              <?php endfor; ?>                          
            </ul> 
            <?php endif; ?>
          </div>
          <?php
          # code...
          break;
        
        case 4: 

        $style = (!empty($instance['image_url'])) ? ' style="background-image:url('.$instance['image_url'].');"':'';

        ?>
        <div class="tt-border-block tt-border-radius">
          <div class="tt-title-block type-2">
              <h3 class="tt-title-text"><?php echo esc_html($title);  ?></h3>
          </div>
          <div class="empty-space marg-lg-b15"></div>
          <div class="tt-popular-post-widget" <?php echo wp_kses_post($style); ?>>
            <div class="tt-popular-post-overlay"></div>
            <ul class="tt-popular-post-list">
              <?php 
                for ($i = 0; $i < $r->post_count; $i ++): $r -> the_post(); 
              ?>
                <li><a href="<?php echo esc_url(get_the_permalink()); ?>"><span><?php echo esc_html($i + 1); ?></span> <?php the_title(); ?></a></li>
              <?php endfor; ?>
            </ul>
          </div>
        </div>
        <?php
          break;
      }

    ?>
      
      <?php
      // Reset the global $the_post as this query will have stomped on it
      wp_reset_postdata();
    endif; //have_posts()
    echo $after_widget;
    $cache[$args['widget_id']] = ob_get_flush();
    wp_cache_set('widget_latest_posts_entries', $cache, 'widget');
  }

  function update( $new_instance, $old_instance )
  {
    $instance              = $old_instance;
    $instance['title']     = strip_tags($new_instance['title']);
    $instance['number']    = (int) $new_instance['number'];
    $instance['cat']       = $new_instance['cat'];
    $instance['image_url'] = $new_instance['image_url'];
    $instance['style']     = intval($new_instance['style']);

    $alloptions = wp_cache_get( 'alloptions', 'options' );
    if ( isset($alloptions['widget_latest_posts_entries']) )
    {
      delete_option('widget_latest_posts_entries');
    }
    return $instance;
  }

  function form( $instance )
  {
    $title     = isset($instance['title']) ? $instance['title'] : '';
    $number    = isset($instance['number']) ? $instance['number'] : 5;
    $cat       = isset($instance['cat']) ? $instance['cat'] : '';
    $image_url = isset($instance['image_url']) ? $instance['image_url'] : '';
    $style     = isset($instance['style']) ? $instance['style'] : 1;
    ?>
    <p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php _e( 'Title:', 'blogit-addons' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'style' )); ?>"><?php esc_html_e( 'Style:', 'splendid-addons' ); ?></label>
    <select class="widefat" id="<?php echo esc_attr($this->get_field_id( 'style' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'style' )); ?>">
      <option value="1" <?php selected( '1', $style ); ?>>Style 1</option>
      <option value="2" <?php selected( '2', $style ); ?>>Style 2</option>    
      <option value="3" <?php selected( '3', $style ); ?>>Style 3</option>    
      <option value="4" <?php selected( '4', $style ); ?>>Style 4</option>    
    </select></p>

    <p><label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php _e( 'Category ID:', 'blogit-addons' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('cat')); ?>" name="<?php echo esc_attr($this->get_field_name('cat')); ?>" type="text" value="<?php echo esc_attr($cat); ?>" /><span class="description" style="padding:0;"><em>Add Catgory ID sepertaed with comma.</em></span></p>

    <p><label for="<?php echo esc_attr($this->get_field_id('image_url')); ?>"><?php _e( 'Background Image URL:', 'blogit-addons' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('image_url')); ?>" name="<?php echo esc_attr($this->get_field_name('image_url')); ?>" type="text" value="<?php echo esc_attr($image_url); ?>" /><span class="description" style="padding:0;"><em>Add background image url ( this is only for style4).</em></span></p>

    <p><label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php _e( 'Number of posts to show:', 'blogit-addons' ); ?></label>
    <input id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>
    <?php
  }
}
