<?php
/**
 * Social Form widget
 *
 * @package blogit
 */

class blogit_WP_Social_Counter_Widget extends WP_Widget {
  function __construct() {
    $widget_ops = array('classname' => 'widget_social_count_entries', 'description' => esc_html__( 'Add Social Counter', 'blogit-addons' ) );
    parent::__construct('social-counter', esc_html__( '- blogit: Social Counter', 'blogit-addons' ), $widget_ops);

    $this->alt_option_name = 'widget_social_count_entries';

    add_action( 'save_post',    array(&$this, 'flush_widget_cache') );
    add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
    add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
  }

  function widget($args, $instance) {
    global $post;

    $cache = wp_cache_get('widget_social_count_entries', 'widget');

    if ( !is_array($cache)) {
      $cache = array();
    }
    if ( ! isset( $args['widget_id'])) {
      $args['widget_id'] = $this->id;
    }

    if ( isset( $cache[ $args['widget_id'] ])) {
      echo $cache[ $args['widget_id'] ];
      return;
    }

    ob_start();
    extract($args);
    echo $before_widget;

    $title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base);

    if ($title):
      echo $before_title.esc_html($title).$after_title;
    endif; 

    $fb_id      = !empty($instance['fb_id']) ? $instance['fb_id']:'';
    $fb_token   = !empty($instance['fb_token']) ? $instance['fb_token']:'';
    $twitter_id = !empty($instance['twitter_id']) ? $instance['twitter_id']:'';
    $youtube_id = !empty($instance['youtube_id']) ? $instance['youtube_id']:'';

    $rs_social_api = new RS_Social_API();

    $social_names = array(
      'facebook' => array(
        'url'      => 'https://www.facebook.com/'.$fb_id,
        'username' => $fb_id,
        'name'     => 'Facebook',
        'text'     => 'Likes',
        'icon'     => 'facebook-f'
      ),
      'twitter' => array(
        'url'      => 'https://www.twitter.com/'.$twitter_id,
        'username' => $twitter_id,
        'name'     => 'Twitter',
        'text'     => 'Followers',
        'icon'     => 'twitter'
      ),
      'youtube' => array(
        'url'      => 'https://www.youtube.com/'.$youtube_id,
        'name'     => 'Youtube',
        'username' => $youtube_id,
        'text'     => 'Followers',
        'icon'     => 'youtube'
      ),
    );

    ob_start();
    $output  = '<div class="tt-social-counter">';
    $output .= '<ul>';

    foreach($social_names as $social_id => $social_name):

      if(empty($social_names[$social_id]['username'])) { continue; }
      $count = $rs_social_api->rs_get_social_counter($social_id, $social_names[$social_id]['username'], $fb_token);

      $output .= '<li class="tt-'.esc_attr($social_id).'"><a href="'.esc_url($social_names[$social_id]['url']).'" target="_blank">';
      $output .= '<div class="tt-social-icon"><i class="fab fa-'.esc_attr($social_names[$social_id]['icon']).'"></i></div>';
      $output .= '<div class="tt-social-name">'.esc_html($social_names[$social_id]['name']).'</div>';
      $output .= '<div class="tt-social-count">'.esc_html($count).' <span>'.esc_html($social_names[$social_id]['text']).'</span></div>';
      $output .= '</a></li>';

    endforeach;
    $output .= '</ul>';
    $output .= '</div>';

    $output .= ob_get_clean();
    echo $output;
    echo $after_widget;
    $cache[$args['widget_id']] = ob_get_flush();
    wp_cache_set('widget_social_count_entries', $cache, 'widget');
  }

  function update($new_instance, $old_instance) {

    $instance               = $old_instance;
    $instance['title']      = strip_tags($new_instance['title']);
    $instance['fb_id']      = $new_instance['fb_id'];
    $instance['fb_token']   = $new_instance['fb_token'];
    $instance['twitter_id'] = $new_instance['twitter_id'];
    $instance['youtube_id'] = $new_instance['youtube_id'];

    $this->flush_widget_cache();

    $alloptions = wp_cache_get( 'alloptions', 'options' );
    if ( isset($alloptions['widget_social_count_entries'])) {
      delete_option('widget_social_count_entries');
    }
    return $instance;
  }

  function flush_widget_cache() {
    wp_cache_delete('widget_social_count_entries', 'widget');
  }

  function form($instance) {
    $title      = isset($instance['title']) ? $instance['title'] : '';
    $fb_id      = isset($instance['fb_id']) ? $instance['fb_id'] : '';
    $fb_token   = isset($instance['fb_token']) ? $instance['fb_token'] : '';
    $twitter_id = isset($instance['twitter_id']) ? $instance['twitter_id'] : '';
    $youtube_id = isset($instance['youtube_id']) ? $instance['youtube_id'] : '';

  ?>
    <p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php _e( 'Title:', 'blogit-addons' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'fb_id' )); ?>"><?php esc_html_e('Facebook ID:','blogit-addons'); ?> <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'fb_id' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'fb_id' )); ?>" type="text" value="<?php echo esc_attr($fb_id); ?>" /><span class="description" style="padding:0; margin-top:5px;display:block;"><em>Enter the page ID or page name.E.g: If your page URL is https://www.facebook.com/ThemeBubble then your page ID is ThemeBubble.</em></span></label></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'fb_token' )); ?>"><?php esc_html_e('Facebook Access Token:','blogit-addons'); ?> <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'fb_token' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'fb_token' )); ?>" type="text" value="<?php echo esc_attr($fb_token); ?>" /><span class="description" style="padding:0; margin-top:5px;display:block;"><em>Refer this video tutorial on how to get access token <a href="https://www.youtube.com/watch?v=_hF099c0A9M">https://www.youtube.com/watch?v=_hF099c0A9M</a></em></span></label></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'twitter_id' )); ?>"><?php esc_html_e('Twitter ID:','blogit-addons'); ?> <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'twitter_id' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitter_id' )); ?>" type="text" value="<?php echo esc_attr($twitter_id); ?>" /></label></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'youtube_id' )); ?>"><?php esc_html_e('Youtube ID:','blogit-addons'); ?> <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'youtube_id' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'youtube_id' )); ?>" type="text" value="<?php echo esc_attr($youtube_id); ?>" /><span class="description" style="padding:0; margin-top:5px;display:block;"><em>If youtube URL is www.youtube.com/user/envato then your youtube id is envato.</em></span></label></p>
    <?php
  }
    
}
