<?php
/**
 * Latest posts widget
 *
 * @package blogit
 */
class blogit_WP_Two_Column_Post_Widget extends WP_Widget
{
  function __construct()
  {
    $widget_ops = array('classname' => 'widget_two_column_post_entries', 'description' => esc_html__( "Displays the posts with two column", 'blogit-addons' ) );
    parent::__construct('two-column-post', esc_html__( '- blogit: Posts Two Column', 'blogit-addons' ), $widget_ops);

    $this->alt_option_name = 'widget_two_column_post_entries';

  }

  function widget($args, $instance)
  {
    global $post;

    extract($args);
    echo $before_widget;
    $title = apply_filters('widget_title', empty($instance['title']) ? esc_html__( 'Popular Posts', 'blogit-addons' ) : $instance['title'], $instance, $this->id_base);
    if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
    {
      $number = 6;
    }

    $cats = !empty($instance['cat']) ? $instance['cat']:'';
    $args = array(
      'meta_query'          => array(array('key' => '_thumbnail_id')), 
      'orderby'             => 'meta_value_num', 
      'order'               => 'DESC', 
      'meta_key'            =>'post_views_count', 
      'posts_per_page'      => $number, 
      'no_found_rows'       => true, 
      'post_status'         => 'publish', 
      'ignore_sticky_posts' => true
    );


    if( $cats ) {
      $args['tax_query'] = array(
        array(
          'taxonomy' => 'category',
          'field'    => 'ids',
          'terms'    => explode( ',', $cats )
        )
      );
    }

    $r = new WP_Query($args);
    if ($r->have_posts()) :

      $post_count = $r->post_count;

    ?>
      
      <div class="tt-border-block tt-border-radius">
        <div class="tt-title-block type-2">
            <h3 class="tt-title-text"><?php echo esc_html($title);  ?></h3>
        </div>
        <div class="empty-space marg-lg-b15"></div>

        <div class="row tt-post-two-col">

          <?php $i = 0;  while ($i < $post_count ): $r -> the_post(); ?>
          <div <?php post_class('tt-post tt-post-two-col-item type-3 col-sm-6 col-md-6'); ?>>
            <?php blogit_post_format('blogit-medium-hor', 'img-responsive', false, '', 'tt-icon-size-small'); ?>
            <div class="tt-post-info">
              <a class="tt-post-title c-h5 small" href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                <?php blogit_blog_author_date(); ?>
            </div>
            <?php echo ($i < $post_count - 2 ) ? '<div class="marg-lg-b30"></div>':'<div class="marg-lg-b20"></div>'; ?>
          </div>
          <?php $i++; endwhile; ?>

        </div>




      </div>

      <?php
      // Reset the global $the_post as this query will have stomped on it
      wp_reset_postdata();
    endif; //have_posts()
    echo $after_widget;
    
  }

  function update( $new_instance, $old_instance )
  {
    $instance           = $old_instance;
    $instance['title']  = strip_tags($new_instance['title']);
    $instance['number'] = (int) $new_instance['number'];
    $instance['cat']    = $new_instance['cat'];

    return $instance;
  }

  function form( $instance )
  {
    $title  = isset($instance['title']) ? $instance['title'] : '';
    $number = isset($instance['number']) ? $instance['number'] : 5;
    $cat    = isset($instance['cat']) ? $instance['cat'] : '';
    ?>
    <p><label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php _e( 'Title:', 'blogit-addons' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id('cat')); ?>"><?php _e( 'Category ID:', 'blogit-addons' ); ?></label>
    <input id="<?php echo esc_attr($this->get_field_id('cat')); ?>" class="widefat" name="<?php echo esc_attr($this->get_field_name('cat')); ?>" type="text" value="<?php echo esc_attr($cat); ?>" size="3" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php _e( 'Number of posts to show:', 'blogit-addons' ); ?></label>
    <input id="<?php echo esc_attr($this->get_field_id('number')); ?>" class="widefat" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>
    <?php
  }
}
