<?php
/**
 * Action Hooks.
 *
 * @package blogit
 * @since 1.0
 */
/**
 * Post Column View
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_posts_custom_column_views')) {
  function blogit_posts_custom_column_views($column_name, $id) {
    if($column_name === 'post_views'){
      echo blogit_getPostViews(get_the_ID());
    }
  }
  add_action('manage_posts_custom_column', 'blogit_posts_custom_column_views',5,2);
}

/**
* @return null
* @param none
* register widgets
**/
if(!function_exists('blogit_enqueue_inline_styles')) {
  function blogit_enqueue_inline_styles() {
    $oArgs = ThemeArguments::getInstance('inline_style');
    $inline_styles = $oArgs -> get('inline_styles');
    if (is_array($inline_styles) && count($inline_styles) > 0) {
      echo '<style id="custom-shortcode-css" scoped type="text/css">'. blogit_css_compress( wp_specialchars_decode( wp_kses_data( join( '', $inline_styles ) ) ) ) .'</style>';
    }
    $oArgs->reset();
  }
  //add_action( 'wp_footer', 'blogit_enqueue_inline_styles' );
}

/**
* @return null
* @param none
* load fontawesome
**/
if(!function_exists('blogit_redux_new_icon_font')) {
  function blogit_redux_new_icon_font() {
    wp_deregister_style( 'redux-elusive-icon' );
    wp_deregister_style( 'redux-elusive-icon-ie7' );
    wp_enqueue_style('font-awesome-admin',     'https://use.fontawesome.com/releases/v5.4.1/css/all.css',null, BLOGIT_THEME_VERSION);
  }
  add_action( 'redux/page/tb_theme_options/enqueue', 'blogit_redux_new_icon_font' );
}

/**
* @return null
* @param none
* editor style
**/
if(!function_exists('blogit_theme_editor_style')) {
  function blogit_theme_editor_style() {
    add_editor_style( 'custom-editor-style.css' );
  }
  add_action( 'admin_init', 'blogit_theme_editor_style' );
}

/**
* @return null
* @param none
* register widgets
**/
if( !function_exists('blogit_register_sidebar') ) {

  function blogit_register_sidebar() {
    register_sidebar(array(
      'id'            => 'main',
      'name'          => esc_html__('Main Sidebar', 'blogit'),
      'before_widget' => '<div id="%1$s" class="sidebar-item widget %2$s">',
      'after_widget'  => '</div><div class="empty-space marg-lg-b30"></div>',
      'before_title'  => '<div class="tt-title-block"><h5 class="c-h5 widget-title tt-title-text">',
      'after_title'   => '</h5></div><div class="empty-space marg-lg-b20"></div>',
      'description'   => 'Drag the widgets for sidebars.'
    ));

    register_sidebar(array(
      'id'            => 'footer-instagram-sidebar',
      'name'          => esc_html__('Footer Instagram Sidebar', 'blogit'),
      'before_widget' => '<div id="%1$s" class="widget tt-footer-instagram footer_widget %2$s">',
      'after_widget'  => '</div>',
      'before_title'  => '<div class="tt-title-block style1 dark"><h3 class="tt-title-text">',
      'after_title'   => '</h3></div><div class="empty-space marg-lg-b25"></div>',
      'description'   => 'Drag the instagram widgets for footer sidebar.'
    ));

    for($i = 1; $i < 5; $i++) {
      register_sidebar(array(
        'id'            => 'footer-'.$i,
        'name'          => esc_html__('Footer Sidebar '.$i, 'blogit'),
        'before_widget' => '<div id="%1$s" class="widget tt-footer-list footer_widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h5 class="tt-title-block-2">',
        'after_title'   => '</h5><div class="empty-space marg-lg-b10"></div>',
        'description'   => 'Drag the widgets for sidebars.'
      ));
    }

    $custom_sidebars = blogit_get_opt('custom-sidebars');
    if (is_array($custom_sidebars)) {
      foreach ($custom_sidebars as $sidebar) {

        if (empty($sidebar)) {
          continue;
        }

        register_sidebar ( array (
          'name'          => $sidebar,
          'id'            => sanitize_title ( $sidebar ),
          'before_widget' => '<div id="%1$s" class="custom-sidebar sidebar-item widget %2$s">',
          'after_widget'  => '</div><div class="empty-space marg-lg-b30"></div>',
          'before_title'  => '<div class="tt-title-block"><h3 class="widget-title tt-title-text">',
          'after_title'   => '</h3></div><div class="empty-space marg-lg-b20"></div>',
        ) );
      }
    }
  }
  add_action( 'widgets_init', 'blogit_register_sidebar' );
}


/**
 * Pagination Redirect
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_pagination_redirect')) {
  function blogit_pagination_redirect() {
    if( is_paged() && !blogit_is_wocommerce() && !is_search() && !is_archive() && !is_home()) {
      get_template_part( 'paged' );
      exit;
    }
  }
  add_action( 'template_redirect', 'blogit_pagination_redirect' );
}

/**
 * Set up homepage and menu
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_set_homepage_menu')) {
  function blogit_set_homepage_menu($demo_active_import, $demo_directory_path) {
    reset( $demo_active_import );
    $current_key = key( $demo_active_import );
    // set menu
    $wbc_menu_array = array( 
      'magazinepro',
      'fashionpro',
      'newspro',
      'sportspro',
      'foodpro',
      'techpro',
      'travelpro',
      'blogpro',
      'viralpro',
      'videopro',
      'fitnesspro',
      'musicpro',
      'healthpro',
      'carpro',
      'femininepro',
      'minimalpro',
      'classicpro',
      'modernpro',
      'cleanpro',
      'luxurypro',
      'photographypro',
      'artpro',
      'designpro',
      'lifestylepro',
      'gamepro',
      'moviepro',
      'gadgetpro',
      'reviewpro',
      'podcastpro',
      'entertainmentpro',
      'girlypro',
      'architecturepro',
      'diypro',
      'cinemapro',
      'personalpro',
      'bitcoinpro',
      'pinpro',
      'recipepro',
      'writerpro',
      'seopro',
      'memepro',
      'affiliatepro',
      'downloadpro',
      'gossippro',
    );
    if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && in_array( $demo_active_import[$current_key]['directory'], $wbc_menu_array ) ) {
      $locations = get_nav_menu_locations();
      $main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
      $top_menu  = get_term_by( 'name', 'Top Menu', 'nav_menu' );

      if ( isset( $top_menu->term_id ) && isset($main_menu->term_id)) {
        set_theme_mod( 'nav_menu_locations', array(
          'top-menu'     => $top_menu->term_id,
          'primary-menu' => $main_menu->term_id,
        ));
      }
    }

    // set homepage
    $wbc_home_pages = array(
      'magazinepro'      => 'Home',
      'fashionpro'       => 'Home',
      'newspro'          => 'Home',
      'sportspro'        => 'Home',
      'foodpro'          => 'Home',
      'techpro'          => 'Home',
      'travelpro'        => 'Home',
      'blogpro'          => 'Home',
      'viralpro'         => 'Home',
      'videopro'         => 'Home',
      'fitnesspro'       => 'Home',
      'musicpro'         => 'Home',
      'healthpro'        => 'Home',
      'carpro'           => 'Home',
      'femininepro'      => 'Home',
      'minimalpro'       => 'Home',
      'classicpro'       => 'Home',
      'modernpro'        => 'Home',
      'cleanpro'         => 'Home',
      'luxurypro'        => 'Home',
      'photographypro'   => 'Home',
      'artpro'           => 'Home',
      'designpro'        => 'Home',
      'lifestylepro'     => 'Home',
      'gamepro'          => 'Home',
      'moviepro'         => 'Home',
      'gadgetpro'        => 'Home',
      'reviewpro'        => 'Home',
      'podcastpro'       => 'Home',
      'entertainmentpro' => 'Home',
      'girlypro'         => 'Home',
      'pinpro'           => 'Home',
      'architecturepro'  => 'Home',
      'diypro'           => 'Home',
      'cinemapro'        => 'Home',
      'personalpro'      => 'Home',
      'bitcoinpro'       => 'Home',
      'recipepro'        => 'Home',
      'writerpro'        => 'Home',
      'seopro'           => 'Home',
      'memepro'          => 'Home',
      'affiliatepro'     => 'Home',
      'downloadpro'      => 'Home',
      'gossippro'        => 'Home',
    );
    if ( isset( $demo_active_import[$current_key]['directory'] ) && !empty( $demo_active_import[$current_key]['directory'] ) && array_key_exists( $demo_active_import[$current_key]['directory'], $wbc_home_pages ) ) {
      $page = get_page_by_title( $wbc_home_pages[$demo_active_import[$current_key]['directory']] );
      if ( isset( $page->ID ) ) {
        update_option( 'page_on_front', $page->ID );
        update_option( 'show_on_front', 'page' );
      }
    }
  }
  add_action( 'wbc_importer_after_content_import', 'blogit_set_homepage_menu', 10, 2 );
}

/**
 * Inactive default widgets after import
 *
 * @package adios
 * @since 1.0
 */
if ( !function_exists( 'blogit_after_content_import' ) ) {
  function blogit_after_content_import( $demo_active_import , $demo_data_directory_path ) {
    $inactive = array();
    $sidebars = wp_get_sidebars_widgets();

    if( isset( $sidebars['wp_inactive_widgets'] ) ) {
      $inactive = $sidebars['wp_inactive_widgets'];
      unset( $sidebars['wp_inactive_widgets'] );
    }

    foreach ( $sidebars as $sidebar => $widgets ) {
      if(is_array($widgets)):
        $inactive = array_merge( $inactive, $widgets );
      endif;
      $sidebars[$sidebar] = array();
    }

    $sidebars['wp_inactive_widgets'] = $inactive;

    wp_set_sidebars_widgets( $sidebars );
  }

  add_action( 'wbc_importer_after_content_import', 'blogit_after_content_import', 10, 2 );
}


/**
* @return null
* @param none
* loads all the js and css script to frontend
**/
if( !function_exists('blogit_enqueue_scripts')) {

  function blogit_enqueue_scripts() {

    if(( is_admin())) { return; }

    if (is_singular()) { wp_enqueue_script( 'comment-reply' ); }

    $google_map_api = blogit_get_opt('google-map-api');

    wp_enqueue_script('blogit-global',         get_theme_file_uri('js/global.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_register_script('swiper',               get_theme_file_uri('js/idangerous.swiper.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_register_script('yt-playlist',          get_theme_file_uri('js/ytv.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_enqueue_script('match-height',          get_theme_file_uri('js/match.height.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    if(blogit_woocommerce_enabled()):
      wp_enqueue_script('formstone',           get_theme_file_uri('js/jquery.formstone.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    endif;
    wp_enqueue_script('appear',                get_theme_file_uri('js/jquery.appear.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_enqueue_script('sloader',               get_theme_file_uri('js/sPreloader.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_enqueue_script('parallax',              get_theme_file_uri('js/parallax.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    wp_register_script('isotope-pkg',          get_theme_file_uri('js/jquery.isotope.min.js'),array('jquery'), BLOGIT_THEME_VERSION,true);
    if(!empty($google_map_api)):
      wp_register_script('gmapsensor',         '//maps.googleapis.com/maps/api/js?key='.esc_attr($google_map_api).'' ,array('jquery'), BLOGIT_THEME_VERSION,true);
      wp_register_script('map',                get_theme_file_uri('js/map.js'),array('gmapsensor'), BLOGIT_THEME_VERSION,true);
    endif;
    wp_enqueue_script('imagesloaded');

    wp_localize_script('blogit-global', 'blogit_ajax',
      array(
        'ajaxurl' => admin_url('admin-ajax.php'),
        'siteurl' => get_template_directory_uri(),
        'nonce'   => wp_create_nonce('blogit-nonce')
      )
    );

    wp_enqueue_style('blogit-fonts',           blogit_fonts_url(), null, BLOGIT_THEME_VERSION );
    wp_enqueue_style('blogit-material-icon',   blogit_material_font_icon(), null, BLOGIT_THEME_VERSION );
    wp_enqueue_style('font-awesome-theme',     'https://use.fontawesome.com/releases/v5.4.1/css/all.css',null, BLOGIT_THEME_VERSION);
    wp_enqueue_style('ytv-playlist',           get_theme_file_uri('css/ytv.css'),null, BLOGIT_THEME_VERSION);
    if(blogit_woocommerce_enabled()):
      wp_enqueue_style('woocommerce',          get_theme_file_uri('css/woocommerce.css'),null, BLOGIT_THEME_VERSION);
    endif;
    wp_enqueue_style('bootstrap-theme',        get_theme_file_uri('css/bootstrap.min.css'),null, BLOGIT_THEME_VERSION);
    wp_register_style('swiper',                get_theme_file_uri('css/idangerous.swiper.css'),null, BLOGIT_THEME_VERSION);
    wp_enqueue_style('blogit-main-style',      get_theme_file_uri('css/style.css'),null, BLOGIT_THEME_VERSION);
    
    if(is_rtl()):
      wp_enqueue_style('rtl',                  get_theme_file_uri('css/rtl.css'),null, BLOGIT_THEME_VERSION);
    endif;

    $pages = array();
  
    if (blogit_get_post_opt('page-show-special-content-after-content')) {
      $pages[] = blogit_get_post_opt('page-after-special-content');
    }

    if (blogit_get_post_opt('page-show-special-content-before-content')) {
      $pages[] = blogit_get_post_opt('page-before-special-content');
    }

  
    if (is_array($pages) && count($pages) > 0) {
      foreach ($pages as $page) {        
        if (empty($page)) { continue; }
        $shortcodes_custom_css = get_post_meta( $page, '_wpb_shortcodes_custom_css', true );
        if(!empty($shortcodes_custom_css)) {
          wp_add_inline_style( 'blogit-main-style', $shortcodes_custom_css );
        }
      }
    }

    $css_code         = blogit_get_opt('css_editor');
    $accent_code      = blogit_accent_css();
    $inline_css       = blogit_get_inline_css(); // get inline css by post id
    $custom_font_face = blogit_custom_font();

    $style = '';
    $style .= ( !empty($css_code) || !empty($accent_code)|| !empty($inline_css) || !empty($custom_font_face)) ? $css_code.$accent_code.$inline_css.$custom_font_face:'';

    wp_add_inline_style('blogit-main-style', $style);
  }
  add_action( 'wp_enqueue_scripts', 'blogit_enqueue_scripts' );
}

/**
 *
 * Customizer Preview
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_customize_preview_init')) {
  function blogit_customize_preview_init(){
    wp_enqueue_script( 'customizer-frontend', get_theme_file_uri('framework/admin/assets/js/customizer.js'), array( 'jquery', 'customize-preview' ), BLOGIT_THEME_VERSION, true );
  }
  add_action( 'customize_preview_init', 'blogit_customize_preview_init' );
}

/**
 *
 * Redux Custom CSS
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_redux_custom_enqueue_scripts')) {
  function blogit_redux_custom_enqueue_scripts() {
    wp_enqueue_style('redux-custom',  get_theme_file_uri('framework/admin/assets/css/redux-custom.css'), array('redux-admin-css'), BLOGIT_THEME_VERSION);
  }
  add_action( 'redux/page/tb_theme_options/enqueue', 'blogit_redux_custom_enqueue_scripts' );
}

/**
 *
 * TGM Register
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(! function_exists('blogit_include_required_plugins')) {

  function blogit_include_required_plugins() {

    $plugins = array(

      array(
        'name'     => 'Redux Framework',
        'slug'     => 'redux-framework',
        'required' => true,
      ),

      array(
        'name'               => esc_html__('Contact Form 7', 'blogit'), 
        'slug'               => 'contact-form-7', 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),   
      array(
        'name'               => esc_html__('Facebook Widget', 'blogit'), 
        'slug'               => 'facebook-pagelike-widget', 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Latest Tweets Widget', 'blogit'), 
        'slug'               => 'latest-tweets-widget', 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Woocommerce', 'blogit'), 
        'slug'               => 'woocommerce', 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Instagram', 'blogit'), 
        'slug'               => 'wp-instagram-widget', 
        'source'             => get_theme_file_uri('plugins/wp-instagram-widget.zip'),
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Visual Composer', 'blogit'), 
        'slug'               => 'js_composer', 
        'source'             => get_theme_file_uri('plugins/js_composer.zip'), 
        'required'           => true, 
        'version'            => '5.4.7', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Yellow Pencil', 'blogit'), 
        'slug'               => 'waspthemes-yellow-pencil',   
        'source'             =>  get_theme_file_uri('plugins/yellow_pencil.zip'), 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Viral Quiz – BuzzFeed', 'blogit'), 
        'slug'               => 'wp-viral-quiz',   
        'source'             =>  get_theme_file_uri('plugins/wp-viral-quiz.zip'), 
        'required'           => false, 
        'version'            => '', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Blogit Addons', 'blogit'), 
        'slug'               => 'blogit-addons',   
        'source'             => get_theme_file_uri('plugins/blogit-addons.zip'), 
        'required'           => true, 
        'version'            => '1.1', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Blogit AMP', 'blogit'), 
        'slug'               => 'blogit-amp',   
        'source'             =>  get_theme_file_uri('plugins/blogit-amp.zip'), 
        'required'           => false, 
        'version'            => '1.0', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Redux Addons', 'blogit'), 
        'slug'               => 'redux-addons',   
        'source'             =>  get_theme_file_uri('plugins/redux-addons.zip'), 
        'required'           => false, 
        'version'            => '1.1', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
      array(
        'name'               => esc_html__('Newsletter', 'blogit'), 
        'slug'               => 'newsletter',   
        'required'           => false, 
        'version'            => '1.2', 
        'force_activation'   => false, 
        'force_deactivation' => false, 
        'external_url'       => '', 
      ),
    );

    $config = array(
      'id'           => 'blogit',              
      'default_path' => '',                      
      'menu'         => 'rs_plugins', 
      'parent_slug'  => 'themes.php',            
      'capability'   => 'edit_theme_options',    
      'has_notices'  => true,                    
      'dismissable'  => true,                    
      'dismiss_msg'  => '',                      
      'is_automatic' => false,                   
      'message'      => '',                      
    );

    tgmpa( $plugins, $config );

  }
  add_action( 'tgmpa_register', 'blogit_include_required_plugins' );
}


/**
 *
 * Ajax Pagination
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if( ! function_exists( 'blogit_ajax_pagination' ) ) {
  function blogit_ajax_pagination() {
    global $post;
    $type           = ( ! empty( $_POST['post_type'] ) ) ? $_POST['post_type'] : 'post';
    $template       = ( ! empty( $_POST['template'] ) ) ? $_POST['template'] : 'list-layout-style1';
    $show_category  = ( ! empty( $_POST['show_category'] ) ) ? $_POST['show_category'] : 'yes';
    $show_date      = ( ! empty( $_POST['show_date'] ) ) ? $_POST['show_date'] : 'yes';
    $show_author    = ( ! empty( $_POST['show_author'] ) ) ? $_POST['show_author'] : 'yes';
    $show_comment   = ( ! empty( $_POST['show_comment'] ) ) ? $_POST['show_comment'] : 'yes';
    $show_views     = ( ! empty( $_POST['show_views'] ) ) ? $_POST['show_views'] : 'yes';
    $show_views     = ( ! empty( $_POST['show_views'] ) ) ? $_POST['show_views'] : 'yes';
    $query_args = array(
      'paged'          => $_POST['paged'],
      'posts_per_page' => $_POST['posts_per_page'],
      'post_type'      => 'post',
      'isotope'        => 0
    );

    query_posts($query_args);

    if($template == 'list-layout-style1'):

    while( have_posts() ) : the_post(); 
      $video_url = get_post_meta($post->ID, 'post-video-url', true);
    ?>

    <div <?php post_class('tt-post type-6 clearfix'); ?>>
      <?php blogit_post_format('blogit-medium-ver', 'img-responsive', false, $video_url); ?>
      <div class="tt-post-info">
        <?php blogit_blog_category($show_category); ?>
        <?php blogit_blog_title('c-h4', true); ?>
        <?php blogit_blog_author_date($show_author, $show_date); ?>
        <?php blogit_blog_excerpt($excerpt_length); ?>
        <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
      </div>
    </div>
    <div class="empty-space marg-lg-b30"></div>

    <?php
    endwhile;
    wp_reset_query();

    elseif($template == 'list-layout-style2'):

      while( have_posts() ) : the_post(); 
      $video_url = get_post_meta($post->ID, 'post-video-url', true);
    ?>

    <div <?php post_class('tt-post type-6 style-1 clearfix'); ?>>
      <?php blogit_post_format('blogit-big-alt', 'img-responsive', false, $video_url); ?>
      <div class="tt-post-info">
        <?php blogit_blog_category($show_category); ?>
        <?php blogit_blog_title('c-h3', true); ?>
        <?php blogit_blog_excerpt($excerpt_length); ?>
        <?php blogit_blog_post_read_more(); ?>
      </div>
    </div>
    <div class="empty-space marg-lg-b30"></div>

    <?php
    endwhile;
    wp_reset_query();

    elseif($template == 'hand-picked-style8'):

      while( have_posts() ) : the_post(); 
      $video_url = get_post_meta($post->ID, 'post-video-url', true);
    ?>

      <div <?php post_class('col-lg-12'); ?>>
        <div class="tt-post tt-border-radius type-10 style-1">
          <?php blogit_post_format('blogit-medium-ver', 'img-responsive', false, '', 'tt-icon-size-medium'); ?>
          <div class="tt-post-info">
            <?php blogit_blog_category($show_category); ?>
            <?php blogit_blog_title('c-h4', false, true, 25); ?>
            <?php blogit_blog_author_date($show_author, $show_date); ?>
            <?php blogit_blog_post_bottom('no', $show_views); ?>
          </div>
        </div>
        <div class="empty-space marg-lg-b20 marg-sm-b20"></div>
      </div><!-- .col -->

    <?php
    endwhile;
    wp_reset_query();

    else: 

    while( have_posts() ) : the_post(); 
      $video_url = get_post_meta($post->ID, 'post-video-url', true);
    ?>

    <div <?php post_class('isotope-item col-xs-12 col-sm-6 col-md-2'); ?>>
      <div class="tt-post type-2">
        <?php blogit_post_format('blogit-medium', 'img-responsive'); ?>
        <div class="tt-post-info">
          <?php blogit_blog_category($show_category); ?>
          <?php blogit_blog_title('c-h5'); ?>
          <?php blogit_blog_author_date($show_author, $show_date); ?>
          <?php blogit_blog_excerpt($excerpt_length); ?>
          <?php blogit_blog_post_bottom($show_comment, $show_views); ?>
        </div>
      </div>
      <div class="empty-space marg-lg-b30 marg-xs-b30"></div>
    </div>

    <?php
    endwhile;
    wp_reset_query();
    endif;

    die();
  }
  add_action('wp_ajax_ajax-pagination', 'blogit_ajax_pagination');
  add_action('wp_ajax_nopriv_ajax-pagination', 'blogit_ajax_pagination');
}

/**
 *
 * Taxonomy Field Background Color
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_edit_taxonomy_field')) {
  function blogit_edit_taxonomy_field($taxonomy) { ?>
    <table class="form-table">
      <tbody>
        <tr class="form-field form-required term-name-wrap">
          <th scope="row"><label for="name"><?php echo esc_html__('Background Color', 'blogit'); ?></label></th>
          <td><input type="text" name="taxonomy_color" id="taxonomy_color" value="<?php echo blogit_taxonomy_color_value($taxonomy->term_id); ?>" class="wp-color-picker-field" data-default-color="#ffffff" />
          <p class="description"><?php echo esc_html__('Set background color for selected category.', 'blogit'); ?></p></td>
        </tr>
      </tbody>
    </table>
    <script type="text/javascript"> jQuery(document).ready(function($) { $('.wp-color-picker-field').wpColorPicker(); }); </script>
  <?php
  }
  add_action('category_edit_form_fields', 'blogit_edit_taxonomy_field');
}

/**
 *
 * Taxonomy Field Background Color
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_save_taxonomy_color')) {
  function blogit_save_taxonomy_color($term_id) {
    if( isset( $_POST['taxonomy_color'])):
      update_term_meta( $term_id, '_term'.$term_id, $_POST['taxonomy_color']);
    endif;
  }
  add_action('edit_term', 'blogit_save_taxonomy_color');
}

/**
 *
 * Hook Color Picker
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_admin_enqueue_scripts')) {
  function blogit_admin_enqueue_scripts($hook) {
    wp_enqueue_style('admin-custom',  get_theme_file_uri('framework/admin/assets/css/admin.css'), BLOGIT_THEME_VERSION);
    
    $output = '';

    $theme_icon        = blogit_get_opt('admin-theme-icon-image');
    $theme_icon_active = blogit_get_opt('admin-theme-icon-image-active');
    $roles             = blogit_get_opt('admin-white-label-user');
    $theme_icon        = (is_array($theme_icon) && !empty($theme_icon['url'])) ? $theme_icon['url']:'';
    $theme_icon_active = (is_array($theme_icon_active) && !empty($theme_icon_active['url'])) ? $theme_icon_active['url']:'';

    if(!empty($theme_icon) || !empty($theme_icon_active)) {
      $output .= (!empty($theme_icon_active)) ? '.wp-has-current-submenu.toplevel_page_rs_theme_welcome .wp-menu-image:before {background-image:url('.esc_url($theme_icon_active).') !important;}':'';
        $output .= (!empty($theme_icon)) ? '.wp-not-current-submenu.toplevel_page_rs_theme_welcome .wp-menu-image:before {background-image:url('.esc_url($theme_icon).') !important;}':'';
    }
    wp_add_inline_style('admin-custom', $output);
    if ($hook === 'term.php'):
      wp_enqueue_style( 'wp-color-picker' );
      wp_enqueue_script( 'wp-color-picker' );
    endif;
  }
  add_action( 'admin_enqueue_scripts', 'blogit_admin_enqueue_scripts' );
}

/**
 *
 * Admin Login Scripts
 * @since 1.0.0
 * @version 1.1.0
 *
 */
if(!function_exists('blogit_admin_login_scripts')) {
  function blogit_admin_login_scripts() {

    $output  = '';

    $bg_image          = blogit_get_opt('admin-login-bg-image');
    $admin_logo        = blogit_get_opt('admin-login-logo');
    $admin_logo_width  = blogit_get_opt('admin-login-logo-width');
    $admin_logo_height = blogit_get_opt('admin-login-logo-height');

    $admin_logo_width  = (!empty($admin_logo_width)) ? $admin_logo_width:$admin_logo['width'];
    $admin_logo_height = (!empty($admin_logo_height)) ? $admin_logo_height:$admin_logo['height'];
    $bg_image          = (is_array($bg_image) && !empty($bg_image['url'])) ? $bg_image['url']:'';
    $admin_logo        = (is_array($admin_logo) && !empty($admin_logo['url'])) ? $admin_logo['url']:'';

    if(!empty($bg_image)) {
      $output .= 'body {';
      $output .= 'background-image:url('.esc_url($bg_image).')!important; background-repeat:no-repeat !important; background-size:cover !important; background-attachment:fixed !important';
      $output .= '}';
    }

    if(!empty($admin_logo)) {
      $output .= '#login h1 a, .login h1 a {';
      $output .= 'background-image:url('.esc_url($admin_logo).')!important;';
      $output .= 'width:'.esc_attr($admin_logo_width).'px !important;';
      $output .= 'height:'.esc_attr($admin_logo_height).'px !important;';
      $output .= 'background-size:'.esc_attr($admin_logo_width).'px '.esc_attr($admin_logo_height).'px;';
      $output .= '}';
    }

    echo '<style type="text/css">' . wp_kses_post($output) . '</style>';
  } 
  add_action('login_enqueue_scripts', 'blogit_admin_login_scripts');
}

/**
 *
 * Post Vote AJAX
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if(!function_exists('blogit_post_vote')) {
  function blogit_post_vote() {
    if(isset($_POST['id']) && wp_verify_nonce($_POST['vote_nonce'], 'blogit-nonce')) {
      $post_id    = $_POST['id'];
      $is_up      = $_POST['is_up'];
      $vote_count = get_post_meta($post_id, '_vote_count', true);

      if($is_up == 'true') {
        $vote_count = ++$vote_count;
      } elseif($is_up == 'false') {
        $vote_count = --$vote_count;
      } else {
        $vote_count = 1;
      }

      update_post_meta($post_id, '_vote_count', $vote_count);
      setcookie('blogit_vote_'. $post_id, $post_id.' '.$is_up, time() + ( 86400 * 7 ), '/');
      echo 'voted';
    } else {
      echo 'error';
    }
    die();
  }
  add_action('wp_ajax_nopriv_post-vote', 'blogit_post_vote');
  add_action('wp_ajax_post-vote', 'blogit_post_vote');
}

/**
 *
 * Post Count AJAX
 * @since 1.0.0
 * @version 1.0.0
 *
 */
if(!function_exists('blogit_post_download')) {
  function blogit_post_download() {
    if(isset($_POST['id']) && wp_verify_nonce($_POST['download_nonce'], 'blogit-nonce')) {
      $post_id    = $_POST['id'];
      $dl_count = get_post_meta($post_id, '_blogit_dl_count', true);

      $dl_count = ++$dl_count;
      update_post_meta($post_id, '_blogit_dl_count', $dl_count);
    } else {
      echo 'error';
    }
    die();
  }
  add_action('wp_ajax_nopriv_post-download', 'blogit_post_download');
  add_action('wp_ajax_post-download', 'blogit_post_download');
}
