<?php
/**
 * The template includes necessary functions for theme.
 *
 * @package blogit
 * @since 1.0
 */
define ('REDUX_OPT_NAME', 'tb_theme_options');
define ('BLOGIT_THEME_VERSION','1.0');
define ('BLOGIT_THEME_ACTIVATED' , true);

update_option('purchase_key', true);

require get_theme_file_path('framework/includes/rs-theme-argument-class.php');
require get_theme_file_path('framework/includes/rs-woocommerce-config.php');
require get_theme_file_path('framework/includes/rs-actions-config.php');
require get_theme_file_path('framework/includes/rs-helper-functions.php');
require get_theme_file_path('framework/includes/rs-frontend-functions.php');
require get_theme_file_path('framework/includes/plugins/tgm/class-tgm-plugin-activation.php');
require get_theme_file_path('framework/includes/rs-filters-config.php');
require get_theme_file_path('framework/includes/rs-menu-walker-class.php');
require get_theme_file_path('framework/includes/rs-schema-validator-class.php');
require get_theme_file_path('framework/admin/admin-init.php');

if( !function_exists('blogit_after_setup')) {

  function blogit_after_setup() {

    add_image_size('blogit-small-hor',      110,  81,  true ); 
    add_image_size('blogit-small',          183,  96,  true ); 
    add_image_size('blogit-small-ver',      225,  305,  true ); 
    add_image_size('blogit-small-alt',      80,   80,  true ); 
    add_image_size('blogit-medium',         394,  218, true ); 
    add_image_size('blogit-medium-ver',     288,  180, true );  
    add_image_size('blogit-medium-hor',     335,  160, true ); 
    add_image_size('blogit-medium-alt',     290,  162, true ); 
    add_image_size('blogit-big-alt',        608,  505, true ); 
    add_image_size('blogit-big',            821,  394, true );
    add_image_size('blogit-big-alt-3',      824,  550, true );
    add_image_size('blogit-big-alt-2',      537,  307, true );

    add_theme_support('post-thumbnails');
    add_theme_support('custom-background');
    add_theme_support('automatic-feed-links' );
    add_theme_support('post-formats', array('video', 'gallery', 'audio', 'aside', 'quote', 'link') );
    add_theme_support('title-tag');
    add_theme_support('bbpress');
    add_theme_support('woocommerce');
    add_theme_support('wc-product-gallery-zoom');
    add_theme_support('wc-product-gallery-lightbox');
    add_theme_support('wc-product-gallery-slider');
    add_theme_support('align-wide');
    add_theme_support('wp-block-styles');
    add_theme_support('responsive-embeds');
    add_theme_support('editor-styles');
    add_editor_style('editor-style.css');

    register_nav_menus (array(
      'top-menu'     => esc_html__( 'Top Menu', 'blogit' ),
      'primary-menu' => esc_html__( 'Main Menu', 'blogit' ),
      'side-menu'    => esc_html__( 'Side Header Menu', 'blogit' ),
    ) );

    load_theme_textdomain('blogit', get_theme_file_uri('languages'));
  }
  add_action( 'after_setup_theme', 'blogit_after_setup' );
}

if ( ! isset( $content_width ) ) {
  $content_width = 1140;
}


$remove_duplicates = blogit_get_opt('general-homepage-duplicate-switch');
if($remove_duplicates):
  add_filter('loop_end', 'blogit_update_duplicate_posts');
  add_filter('blogit_block_query_args', 'blogit_add_duplicate_exclude');
endif;
/**
 * Action callback: Add to list processed posts to handle duplicates
 * 
 * @param object $query
 */
global $blogit_registry;
$blogit_registry = array();
if(!function_exists('blogit_update_duplicate_posts')) {
  function blogit_update_duplicate_posts(&$query) {
    global $blogit_registry;
    if (empty($query->query_vars['handle_duplicates'])) {
      return;
    }

    foreach ($query->posts as $post) {
      $duplicates = (array) $blogit_registry['page_duplicate_posts'];
      array_push($duplicates, $post->ID); 
      $blogit_registry['page_duplicate_posts'] = $duplicates;
    }
  }
}

/**
 * Filter callback: Enable duplicate prevention on these query args
 * 
 * @param array $query  query arguments
 */
if(!function_exists('blogit_add_duplicate_exclude')) {
  function blogit_add_duplicate_exclude($query) {
    global $blogit_registry;
    if (!is_front_page()) {
      return $query;
    }
    
    if (!isset($blogit_registry['page_duplicate_posts'])) {
      $blogit_registry['page_duplicate_posts'] = array();
    }
    
    $query['post__not_in'] = $blogit_registry['page_duplicate_posts'];
    $query['handle_duplicates'] = true;
        
    return $query;
  }
}
