<?php
/**
 * Slider Style 28
 *
 * @package blogit
 * @since 1.0
 */
?>


<?php
  wp_enqueue_script('swiper');
  wp_enqueue_style('swiper');

  $posts_per_page    = blogit_get_opt('slider-posts-per-page');
  $slider_top_margin = blogit_get_opt('slider-margin-top');
  $slider_order      = blogit_get_opt('slider-post-order');
  $slider_orderby    = blogit_get_opt('slider-post-orderby');
  $slider_style      = (!empty($slider_top_margin) || $slider_top_margin == 0) ? ' style="padding-top:'.esc_attr($slider_top_margin).'px;"':'';
  $args = array(
    'orderby'        => $slider_orderby,
    'order'          => $slider_order,
    'posts_per_page' => $posts_per_page,
    'meta_query'     => array(array('key' => '_thumbnail_id')),
  );


  $categories = blogit_get_opt('slider-category');
  if (is_array($categories)) {
    $args['category__in'] =  $categories;
  }

  $the_query = new WP_Query(apply_filters('blogit_block_query_args', $args, 'slider'));

  if($the_query->have_posts() && $posts_per_page >= 3): 

?>

  <div class="container">
    <div class="row">
      <div class="col-lg-12">
        <div class="tt-slider-outer tt-slider-style28"<?php echo wp_kses_data($slider_style); ?>>
          <div class="tt-slider-width10">
            <div class="arrow-closest tt-mag-slider tt-slider-custom-marg mobile-show-pagination tt-slider-style20 tt-slider-type1">
              <div class="swiper-container" data-mode="horizontal" data-effect="slide" data-slides-per-view="1" data-sm-slides="1" data-xs-slides="1" data-autoplay="<?php echo blogit_get_opt('slider-autoplay'); ?>" data-loop="<?php echo blogit_get_opt('slider-loop-switch'); ?>" data-speed="<?php echo blogit_get_opt('slider-speed'); ?>">
                  <div class="swiper-wrapper<?php echo (!blogit_get_opt('slider-swipe-switch')) ? ' swipe-disabled':''; ?>">

                    <?php

                      $the_posts = array();
                      if( $the_query->have_posts() ):
                        while( $the_query->have_posts() ) : $the_query->the_post();
                          $image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
                          $image = ( ! empty( $image ) ) ? $image[0] : '';
                          $the_posts[] = array(
                            'id'              => get_the_id(),
                            'title'           => get_the_title(),
                            'image'           => $image,
                            'category'        => get_the_category(),
                            'permalink'       => get_the_permalink(),
                            'excerpt'         => blogit_auto_post_excerpt(25),
                            'gradient_enable' => blogit_get_post_opt('post-enable-custom-overlay'),
                            'color_first'     => blogit_get_post_opt('post-overlay-first-color'),
                            'color_second'    => blogit_get_post_opt('post-overlay-second-color')
                          );
                        endwhile;
                        wp_reset_postdata();
                      endif;
                      
                      if(!empty($the_posts)):

                        $total_posts      = count($the_posts);
                        $outer_loop_count = floor($total_posts / 3);
                        $offset_from      = 0;
                        $offset_to        = 3;

                        for($i = 1; $i <= $outer_loop_count; $i++): 
                      ?>

                          <div class="swiper-slide">
                            <div class="tt-inner-padd5">
                              <div class="row">

                                <?php
                                  $post_key = 1; 
                                  for($j = $offset_from; $j < $offset_to; $j++):
                                    $width_class = array('col-lg-3 col-md-4', 'col-lg-6 col-md-4', 'col-lg-3 col-md-4');
                                    $gradient_style = ($the_posts[$j]['gradient_enable'] && !empty($the_posts[$j]['color_first']) || !empty($the_posts[$j]['color_second'])) ? ' style="background: -webkit-linear-gradient(bottom, '. $the_posts[$j]['color_first'] .', '. $the_posts[$j]['color_second'] .' );background: linear-gradient(to bottom, '. $the_posts[$j]['color_first'] .', '. $the_posts[$j]['color_second'] .' ); opacity:0.8;"':''; 

                                ?>
                                  <div class="<?php echo esc_attr($width_class[$post_key - 1]); ?>">
                                    <div class="tt-slider-post tt-style1">
                                      <div class="bg" style="background-image:url(<?php echo esc_url($the_posts[$j]['image']); ?>)"></div>
                                      <div class="bg tt-blurry-img" style="background-image:url(<?php echo esc_url($the_posts[$j]['image']); ?>)"></div>
                                      <a href="<?php echo esc_url($the_posts[$j]['permalink']); ?>" class="tt-mslide-link"></a>
                                      <div class="tt-slider-overlay" <?php echo wp_kses_post($gradient_style); ?>></div>
                                      <div class="tt-slider-text">
                                        <?php 
                                          $category = $the_posts[$j]['category']; 
                                          if(is_array($category) && !empty($category)):
                                            foreach($category as $cat): ?>
                                              <a class="tt-category<?php echo !empty(blogit_slider_category_bg_color($cat->term_id)) ? ' custom-category-color':''; ?>" <?php echo blogit_slider_category_bg_color($cat->term_id); ?> href="<?php echo esc_url(get_category_link($cat->term_id)); ?>"><?php echo esc_html($cat->cat_name); ?></a>
                                           <?php 
                                            endforeach;
                                          endif;
                                        ?>
                                        <h3 class="tt-slider-title">
                                          <a href="<?php echo esc_url($the_posts[$j]['permalink']); ?>"><?php echo esc_html($the_posts[$j]['title']); ?></a>
                                        </h3>
                                        <?php if(!empty($the_posts[$j]['excerpt'])): ?>
                                          <div class="tt-slider-desc"><?php echo esc_html($the_posts[$j]['excerpt']); ?></div>
                                        <?php endif; ?>
                                      </div>
                                    </div>
                                  </div> 
                                <?php if($post_key % 3 == 0) { break; } $post_key++; endfor; ?>

                              </div>
                            </div>
                          </div><!-- .swiper-slide -->

                        <?php 
                          $offset_from = $offset_to;
                          $offset_to   = $offset_from + 3;
                      endfor; 
                    endif; ?>
                  </div>
                  <div class="pagination pagination-hidden c-pagination"></div>
                  <div class="swiper-arrow-left <?php echo (!blogit_get_opt('slider-show-pagination-switch')) ? 'hidden-lg':''; ?> tt-swiper-arrow-3"><i class="fa fa-chevron-left" aria-hidden="true"></i></div>
                  <div class="swiper-arrow-right <?php echo (!blogit_get_opt('slider-show-pagination-switch')) ? 'hidden-lg':''; ?> tt-swiper-arrow-3"><i class="fa fa-chevron-right" aria-hidden="true"></i></div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
<?php else: ?>
  <div class="container">
    <div class="empty-space marg-lg-b55"></div>
    <div class="tt-slider-info">
      <span><?php echo esc_html__('Attention !! Slider must contain atleast 3 post and should be multiple of 3.', 'blogit'); ?></span>
    </div>
  </div>
<?php endif; ?>
