<?php
/**
 * Filter Hooks
 *
 * @package make
 * @since 1.0
 */

/**
 * Title Filter
 *
 * @package make
 * @since 1.0
 */
if (! function_exists('blogit_wp_title') ) {
  function blogit_wp_title( $title, $sep ) {
    global $paged, $page;

    if ( is_feed() ) {
      return $title;
    } // end if

    // Add the site name.
    $title .= get_bloginfo( 'name' );

    // Add the site description for the home/front page.
    $site_description = get_bloginfo( 'description', 'display' );
    if ( $site_description && ( is_home() || is_front_page() ) ) {
      $title = "$title $sep $site_description";
    } // end if

    // Add a page number if necessary.
    if ( $paged >= 2 || $page >= 2 ) {
      $title = sprintf( __( 'Page %s', 'blogit' ), max( $paged, $page ) ) . " $sep $title";
    } // end if

    return $title;

  } // end rs_wp_title
  add_filter( 'wp_title', 'blogit_wp_title', 10, 2 );
}

/**
 * Allow xml file to upload
 *
 * @package adios
 * @since 1.0
 */
if(!function_exists('blogit_upload_svg')) {
  function blogit_upload_svg($mimes) {
    $mimes['svg']  = 'image/svg+xml';
    $mimes['ttf']  = 'font/ttf';
    $mimes['eot']  = 'font/eot';
    $mimes['svg']  = 'font/svg';
    $mimes['woff'] = 'font/woff';
    $mimes['otf']  = 'font/otf';
    $mimes['zip']  = 'application/zip';
    $mimes['gz']   = 'application/x-gzip';
    return $mimes;
  }
  add_filter('upload_mimes', 'blogit_upload_svg');
}

/**
 * Post Column View
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_posts_column_views')) {
  function blogit_posts_column_views($defaults) {
    $defaults['post_views'] = blogit_translate('views', 'Views');
    return $defaults;
  }
  add_filter('manage_posts_columns', 'blogit_posts_column_views');
}

/**
 * Avatar img class
 *
 * @package make
 * @since 1.0
 */
if( !function_exists('blogit_add_gravatar_class')) {
  function blogit_add_gravatar_class( $class ) {
    if(!is_admin()) {
      $class = str_replace("class='avatar", "class='tt-comment-form-ava", $class);
    }
    return $class;
  }
  add_filter('get_avatar','blogit_add_gravatar_class');
}

/**
 * Body Filter Hook
 *
 * @package make
 * @since 1.0
 */
if( !function_exists('blogit_body_class')) {
  function blogit_body_class($classes) {
    $top_header    = blogit_get_opt('top-header-enable');
    $sticky_header = blogit_get_opt('header-enable-sticky-switch');
    $sticky_footer = blogit_get_opt('footer-enable-sticky');
    $classes[] = '';
    $classes[] = blogit_get_opt('page-layout');
    $classes[] = blogit_get_opt('header-template');
    $classes[] = ($top_header) ? 'tt-top-header-enable':'tt-top-header-disable';
    $classes[] = ($top_header) ? 'tt-top-header-enable':'tt-top-header-disable';
    $classes[] = ($sticky_header) ? 'tt-header-sticky':'tt-disable-sticky';
    $classes[] = ($sticky_footer) ? 'tt-sticky-footer':'tt-footer-disable-sticky';
    return $classes;
  }
  add_filter('body_class', 'blogit_body_class');
}

/**
 * Add Custom Class
 *
 * @package make
 * @since 1.0
 */
if(!function_exists('blogit_post_link_next_class')) {
  function blogit_post_link_next_class($format){
   $format = str_replace('href=', 'class="tt-blog-nav-title" href=', $format);
   return $format;
  }
  add_filter('next_post_link', 'blogit_post_link_next_class');
}

/**
 * Add Custom Class
 *
 * @package make
 * @since 1.0
 */
if(!function_exists('blogit_post_link_prev_class')) {
  function blogit_post_link_prev_class($format) {
   $format = str_replace('href=', 'class="tt-blog-nav-title" href=', $format);
   return $format;
  }
  add_filter('previous_post_link', 'blogit_post_link_prev_class');
}

/**
 * Allow demo name to be changed
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_importer_filter_title')) {
  function blogit_importer_filter_title( $title ) {
    $output = trim( ucfirst( str_replace( 'pro', ' ', $title ) ) );
    return $output .' Pro';
  }
  add_filter( 'wbc_importer_directory_title', 'blogit_importer_filter_title', 10 );
}

/**
 * Filter for changing importer description info in options panel
 * when not setting in Redux config file.
 *
 * @param [string] $title description above demos
 *
 * @return [string] return.
 */
if ( !function_exists( 'blogit_importer_description_text' ) ) {

  function blogit_importer_description_text( $description ) {
    $message = wp_kses_data('<i><strong>Note:</strong> Please wait 2-3 minutes depending upon your connection, if importer doesn\'t working as expected then, refer this <a href="#">article</a></i>');
    return $message;
  }
  add_filter( 'wbc_importer_description', 'blogit_importer_description_text', 10 );
}

/**
 * Rename Post Format to Review
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_rename_post_formats')) {
  function blogit_rename_post_formats($translation, $text, $context, $domain) {
    $names = array(
      'Aside' => 'Review',
      'Link'  => 'Download',
    );
    if ($context == 'Post format') {
      $translation = str_replace(array_keys($names), array_values($names), $text);
    }
    return $translation;
  }
  add_filter('gettext_with_context', 'blogit_rename_post_formats', 10, 4);
}

/**
 * Latest Tweet Render
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_latest_tweets_render_tweet') && function_exists('latest_tweets_render')) {
  function blogit_latest_tweets_render_tweet($html, $date, $link, array $tweet) {
    $pic = $tweet['user']['profile_image_url_https'];
    return '<p class="my-tweet"><img src="'.$pic.'"/>'.$html.'</p><p class="my-date"><a href="'.$link.'">'.$date.'</a></p>';
  }
  add_filter('latest_tweets_render_tweet', 'blogit_latest_tweets_render_tweet', 10, 4);
}

/**
 * blogit_facebook_post_thumbnail
 *
 * @package blogit
 * @since 1.0
 */
if(!function_exists('blogit_social_post_thumbnail')) {
  function blogit_social_post_thumbnail() { 
    $social_image = wp_get_attachment_image_src(get_post_thumbnail_id( get_the_ID() ), 'blogit-medium');
  ?>
    <meta property="og:image" content="<?php echo esc_url($social_image[0]); ?>"/>
    <meta name="twitter:image:src" content="<?php echo esc_url($social_image[0]); ?>">
  <?php
  }
  add_filter('wp_head', 'blogit_social_post_thumbnail');
}

/**
 * blogit_exclude_page_from_search
 *
 * @package blogit
 * @since 2.5
 */
if(!function_exists('blogit_exclude_page_from_search')) {
  function blogit_exclude_page_from_search($query) {
    if ($query->is_search && !is_admin()) {
      $query->set('post_type', 'post');
    }
    return $query;
  }
  add_filter('pre_get_posts','blogit_exclude_page_from_search');
}

/**
 * blogit_add_content_in_between_post
 *
 * @package blogit
 * @since 2.5
 */
if(!function_exists('blogit_add_content_in_between_post')) {
  function blogit_add_content_in_between_post($content) {
    $inline_related_post = blogit_get_opt('inline-related-post-enable');
    if (is_single() && !is_admin() && $inline_related_post) {
      return blogit_insert_after_row($content );
    }
    return $content;
  }
  add_action('the_content', 'blogit_add_content_in_between_post');
}

/**
 * append custom fonts
 *
 * @package blogit
 * @since 2.5
 */
if(!function_exists('blogit_custom_fonts')) {
  function blogit_custom_fonts($array) { 
    $custom_font_array = array();
    $custom_fonts      = blogit_get_opt('custom_fonts');
    if(!empty($custom_fonts['name']) && is_array($custom_fonts['name'])) {
      foreach($custom_fonts['name'] as $name) {
        $custom_font_array[$name] = $name;
      }
    }
    if(!empty($custom_font_array)) {
      $array = array('Custom Fonts' => $custom_font_array);
    }
    return $array; 
  }
  add_filter('redux/tb_theme_options/field/typography/custom_fonts', 'blogit_custom_fonts', 10, 1);
}
