<?php
/**
 * Slider Style 27
 *
 * @package blogit
 * @since 1.0
 */
?>


<?php
  wp_enqueue_script('swiper');
  wp_enqueue_style('swiper');

  $posts_per_page    = blogit_get_opt('slider-posts-per-page');
  $slider_top_margin = blogit_get_opt('slider-margin-top');
  $slider_order      = blogit_get_opt('slider-post-order');
  $slider_orderby    = blogit_get_opt('slider-post-orderby');
  $slider_style      = (!empty($slider_top_margin) || $slider_top_margin == 0) ? ' style="padding-top:'.esc_attr($slider_top_margin).'px;"':'';
  $args = array(
    'orderby'        => $slider_orderby,
    'order'          => $slider_order,
    'posts_per_page' => $posts_per_page,
    'meta_query'     => array(array('key' => '_thumbnail_id')),
  );


  $categories = blogit_get_opt('slider-category');
  if (is_array($categories)) {
    $args['category__in'] =  $categories;
  }

  $the_query = new WP_Query(apply_filters('blogit_block_query_args', $args, 'slider'));

  if($the_query->have_posts() && $posts_per_page >= 3): 

?>
  <div class="container">
   <div class="row">
      <div class="col-lg-12">
        <div class="tt-slider-outer tt-slider-style30"<?php echo wp_kses_data($slider_style); ?>>
          <div class="tt-slider-width10">
            <div class="arrow-closest tt-mag-slider tt-slider-custom-marg mobile-show-pagination tt-slider-style19 tt-slider-type1">
              <div class="swiper-container" data-autoplay="<?php echo blogit_get_opt('slider-autoplay'); ?>" data-loop="<?php echo blogit_get_opt('slider-loop-switch'); ?>" data-speed="<?php echo blogit_get_opt('slider-speed'); ?>" data-center="0"  data-slides-per-view="responsive" data-xs-slides="1" data-sm-slides="2" data-md-slides="2" data-lg-slides="3" data-add-slides="3">
                  <div class="swiper-wrapper<?php echo (!blogit_get_opt('slider-swipe-switch')) ? ' swipe-disabled':''; ?>">
                    <?php 
                      while( $the_query->have_posts() ) : $the_query->the_post();
                        $image_src       = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
                        $image_src       = (!empty($image_src) && is_array($image_src)) ? $image_src[0]:'';
                        $gradient_enable = blogit_get_post_opt('post-enable-custom-overlay');
                        $color_first     = blogit_get_post_opt('post-overlay-first-color');
                        $color_second    = blogit_get_post_opt('post-overlay-second-color');
            
                        $gradient_style = ($gradient_enable && !empty($color_first) || !empty($color_second)) ? ' style="background: -webkit-linear-gradient(bottom, '. $color_first .', '. $color_second .' );background: linear-gradient(to bottom, '. $color_first .', '. $color_second .' ); opacity:0.8;"':'';  
                    ?>

                    <div class="swiper-slide">
                      <div class="tt-inner-padd5">
                        <div class="tt-slider-post tt-style1">
                          <div class="bg" style="background-image:url(<?php echo esc_url($image_src); ?>);"></div>
                          <div class="bg tt-blurry-img" style="background-image:url(<?php echo esc_url($image_src); ?>);"></div>
                          <a href="<?php echo esc_url(get_the_permalink()); ?>" class="tt-mslide-link"></a>
                          <div class="tt-slider-overlay"<?php echo wp_kses_post($gradient_style); ?>></div>
                          <div class="tt-slider-text">
                            <?php 
                              $category = get_the_category();
                              if(is_array($category) && !empty($category)):
                                foreach($category as $cat): ?>
                                  <a class="tt-category<?php echo !empty(blogit_slider_category_bg_color($cat->term_id)) ? ' custom-category-color':''; ?>" <?php echo blogit_slider_category_bg_color($cat->term_id); ?> href="<?php echo esc_url(get_category_link($cat->term_id)); ?>"><?php echo esc_html($cat->cat_name); ?></a>
                               <?php 
                                endforeach;
                              endif;
                            ?>
                            <h3 class="tt-slider-title">
                              <a href="<?php echo esc_url(get_the_permalink()); ?>"><?php the_title(); ?></a>
                            </h3>
                            <div class="tt-slider-desc"><?php echo blogit_auto_post_excerpt(15); ?></div>
                          </div>
                        </div>
                      </div>
                    </div>
                    <?php endwhile; wp_reset_postdata(); ?>
                  </div>
                  <div class="pagination pagination-hidden c-pagination"></div>
                  <div class="swiper-arrow-left <?php echo (!blogit_get_opt('slider-show-pagination-switch')) ? 'hidden-lg':''; ?> tt-swiper-arrow-3"><i class="fa fa-chevron-left" aria-hidden="true"></i></div>
                  <div class="swiper-arrow-right <?php echo (!blogit_get_opt('slider-show-pagination-switch')) ? 'hidden-lg':''; ?> tt-swiper-arrow-3"><i class="fa fa-chevron-right" aria-hidden="true"></i></div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
<?php else: ?>
  <div class="container">
    <div class="empty-space marg-lg-b55"></div>
    <div class="tt-slider-info">
      <span><?php echo esc_html__('Attention !! Slider must contain atleast 3 post.', 'blogit'); ?></span>
    </div>
  </div>
<?php endif; ?>
